@@ -3,9 +3,9 @@
  *  for Vedic and western astrology.
 
  *  File       src/dialogs/VedicCalculationPanel.cpp
- *  Release    6.0
- *  Author     M. Pettau
- *  Copyright  2003-2010 by the author
+ *  Release    7.0
+ *  Author     Martin Pettau
+ *  Copyright  2003-2012 by the author
 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -17,9 +17,9 @@
  * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
 ****************************************************************************/
-    
+
 #ifdef __GNUG__
-	#pragma implementation "VedicCalculationPanel.h"
+#pragma implementation "VedicCalculationPanel.h"
 #endif
 
 #include "VedicCalculationPanel.h"
@@ -48,11 +48,11 @@ IMPLEMENT_CLASS( VedicCalculationPanel, ConfigPanel )
 
 /*****************************************************
 **
-**   VedicCalculationPanel   ---   Constructor 
+**   VedicCalculationPanel   ---   Constructor
 **
 ******************************************************/
 VedicCalculationPanel::VedicCalculationPanel( wxWindow* parent )
- : ConfigPanel( parent )
+		: ConfigPanel( parent )
 {
     // begin wxGlade: VedicCalculationPanel::VedicCalculationPanel
     sizer_av_staticbox = new wxStaticBox(this, -1, _("Ashtaka Varga"));
@@ -168,31 +168,31 @@ VedicCalculationPanel::VedicCalculationPanel( wxWindow* parent )
     do_layout();
     // end wxGlade
 
-  Connect( CD_KALAVELA_CHOICE, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler( VedicCalculationPanel::OnKalaVelaChoice ));
-  Connect( CD_KALAVELA_LORD_CHOICE, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler( VedicCalculationPanel::OnKalaVelaLordChoice ));
-  Connect( CD_KALAVELA_PORTION_CHOICE, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler( VedicCalculationPanel::OnKalaVelaPortionChoice ));
-  Connect( CD_KALAVELA_DEFAULT, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( VedicCalculationPanel::OnKalaVelaDefault ));
+	Connect( CD_KALAVELA_CHOICE, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler( VedicCalculationPanel::OnKalaVelaChoice ));
+	Connect( CD_KALAVELA_LORD_CHOICE, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler( VedicCalculationPanel::OnKalaVelaLordChoice ));
+	Connect( CD_KALAVELA_PORTION_CHOICE, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler( VedicCalculationPanel::OnKalaVelaPortionChoice ));
+	Connect( CD_KALAVELA_DEFAULT, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( VedicCalculationPanel::OnKalaVelaDefault ));
 }
 
 /*****************************************************
 **
-**   VedicCalculationPanel   ---   setData 
+**   VedicCalculationPanel   ---   setData
 **
 ******************************************************/
 void VedicCalculationPanel::setData()
 {
-  choice_house->SetSelection( config->vHouseSystem ? config->vHouseSystem -1 : 0 );
-  check_westernhouse->SetValue( config->vHouseWestern );
-  choice_node->SetSelection( config->vLunarNodeMode );
+	choice_house->SetSelection( config->vHouseSystem ? config->vHouseSystem -1 : 0 );
+	check_westernhouse->SetValue( config->vHouseWestern );
+	choice_node->SetSelection( config->vLunarNodeMode );
 
 	// Ashataka Varga
-  choice_av_calcrules->SetSelection( config->vAshtakavargaMode );
+	choice_av_calcrules->SetSelection( config->vAshtakavargaMode );
 	choice_av_benefics->SetSelection( config->vAshtakavargaNumberMode );
-  choice_av_sarva->SetSelection( config->vAshtakavargaSarva );
+	choice_av_sarva->SetSelection( config->vAshtakavargaSarva );
 	choice_av_sodhya->SetSelection( config->vAshtakavargaMantreswarMode );
 
 	// Kala Vela
-	for( int i = 0; i < 6; i++ )
+	for ( int i = 0; i < 6; i++ )
 	{
 		kalaVelaCfgLord[i] = config->kalaVelaLord[i];
 		kalaVelaCfgPortion[i] = config->kalaVelaPortion[i];
@@ -207,29 +207,29 @@ void VedicCalculationPanel::setData()
 	choice_mercury->SetSelection( config->vMercuryBenefic );
 
 	// Misc
-  choice_arudha->SetSelection( config->vArudhaMode );
+	choice_arudha->SetSelection( config->vArudhaMode );
 }
 
 /*****************************************************
 **
-**   VedicCalculationPanel   ---   saveData 
+**   VedicCalculationPanel   ---   saveData
 **
 ******************************************************/
 bool VedicCalculationPanel::saveData()
 {
-  config->vHouseSystem = choice_house->GetSelection() + 1;
-  config->vHouseWestern = check_westernhouse->GetValue();
-  config->vLunarNodeMode = choice_node->GetSelection();
+	config->vHouseSystem = choice_house->GetSelection() + 1;
+	config->vHouseWestern = check_westernhouse->GetValue();
+	config->vLunarNodeMode = choice_node->GetSelection();
 	config->vAyanamsa = choice_vcalc_aya->getConfigIndex();
 
 	// Ashataka Varga
-  config->vAshtakavargaMode = choice_av_calcrules->GetSelection();
+	config->vAshtakavargaMode = choice_av_calcrules->GetSelection();
 	config->vAshtakavargaNumberMode = choice_av_benefics->GetSelection();
-  config->vAshtakavargaSarva = choice_av_sarva->GetSelection();
+	config->vAshtakavargaSarva = choice_av_sarva->GetSelection();
 	config->vAshtakavargaMantreswarMode =	choice_av_sodhya->GetSelection();
-	
+
 	// Kala Vela
-	for( int i = 0; i < 6; i++ )
+	for ( int i = 0; i < 6; i++ )
 	{
 		config->kalaVelaLord[i] = kalaVelaCfgLord[i];
 		config->kalaVelaPortion[i] = kalaVelaCfgPortion[i];
@@ -298,8 +298,8 @@ void VedicCalculationPanel::OnKalaVelaDefault( wxCommandEvent& )
 	kalaVelaCfgLord[3] = KALAVELA_LORD5;     // Yamagantaka - Jupiter
 	kalaVelaCfgLord[4] = KALAVELA_LORD7;     // Gulika - Saturn
 	kalaVelaCfgLord[5] = KALAVELA_LORD_NONE; // Mandi - None
-	for( int i = 0; i < 6; ) kalaVelaCfgPortion[i++] = KALAVELA_PORTION_START;
-	
+	for ( int i = 0; i < 6; ) kalaVelaCfgPortion[i++] = KALAVELA_PORTION_START;
+
 	choice_kalalord->SetSelection( kalaVelaCfgLord[selkala] + 1 );
 	choice_kalaportion->SetSelection( kalaVelaCfgPortion[selkala] );
 	choice_kalaportion->Enable( kalaVelaCfgPortion[selkala] != -1 );
@@ -307,7 +307,7 @@ void VedicCalculationPanel::OnKalaVelaDefault( wxCommandEvent& )
 
 /*****************************************************
 **
-**   VedicCalculationPanel   ---   set_properties 
+**   VedicCalculationPanel   ---   set_properties
 **
 ******************************************************/
 void VedicCalculationPanel::set_properties()
@@ -334,7 +334,7 @@ void VedicCalculationPanel::set_properties()
 
 /*****************************************************
 **
-**   VedicCalculationPanel   ---   do_layout 
+**   VedicCalculationPanel   ---   do_layout
 **
 ******************************************************/
 void VedicCalculationPanel::do_layout()
@@ -403,3 +403,13 @@ void VedicCalculationPanel::do_layout()
     // end wxGlade
 }
 
+/*****************************************************
+**
+**   ConfigPanelFactory   ---   createVedicCalculationPanel
+**
+******************************************************/
+ConfigPanel *ConfigPanelFactory::createVedicCalculationPanel( wxWindow *parent )
+{
+	return new VedicCalculationPanel( parent );
+}
+
