@@ -3,9 +3,9 @@
  *  for Vedic and western astrology.
 
  *  File       src/dialogs/VedicPanel.cpp
- *  Release    6.0
- *  Author     M. Pettau
- *  Copyright  2003-2010 by the author
+ *  Release    7.0
+ *  Author     Martin Pettau
+ *  Copyright  2003-2012 by the author
 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -19,18 +19,15 @@
 ****************************************************************************/
 
 #ifdef __GNUG__
-	#pragma implementation "VedicPanel.h"
+#pragma implementation "VedicPanel.h"
 #endif
 
 #include "VedicPanel.h"
 
 #include <wx/button.h>
 #include <wx/checkbox.h>
-#include <wx/cmndata.h>
 #include <wx/choice.h>
 #include <wx/choicdlg.h>
-#include <wx/colour.h>
-#include <wx/colordlg.h>
 #include <wx/sizer.h>
 #include <wx/statbox.h>
 #include <wx/statline.h>
@@ -40,6 +37,8 @@
 #include "Conf.h"
 #include "guibase.h"
 #include "Lang.h"
+#include "PlanetList.h"
+#include "Writer.h"
 
 extern Config *config;
 
@@ -49,11 +48,11 @@ IMPLEMENT_CLASS( VedicPanel, ConfigPanel )
 
 /*****************************************************
 **
-**   VedicPanel   ---   Constructor 
+**   VedicPanel   ---   Constructor
 **
 ******************************************************/
 VedicPanel::VedicPanel( wxWindow* parent )
- : ConfigPanel( parent )
+		: ConfigPanel( parent )
 {
     // begin wxGlade: VedicPanel::VedicPanel
     panel_arabic_selection = new wxPanel(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxTAB_TRAVERSAL);
@@ -103,62 +102,94 @@ VedicPanel::VedicPanel( wxWindow* parent )
     do_layout();
     // end wxGlade
 
-  Connect( CD_ARABIC, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( VedicPanel::OnArabicParts ));
+	Connect( CD_ARABIC, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( VedicPanel::OnArabicParts ));
 }
 
 /*****************************************************
 **
-**   VedicPanel   ---   setData 
+**   VedicPanel   ---   setData
 **
 ******************************************************/
 void VedicPanel::setData()
 {
-  check_objects_outer->SetValue( config->vObjects & OBJECTS_INCLUDE_OUTER );
+	check_objects_outer->SetValue( config->vObjects & OBJECTS_INCLUDE_OUTER );
 	check_objects_dragonhead->SetValue( config->vObjects & OBJECTS_INCLUDE_DRAGONHEAD );
 	check_objects_dragontail->SetValue( config->vObjects & OBJECTS_INCLUDE_DRAGONTAIL );
 	check_objects_ascendant->SetValue( config->vObjects & OBJECTS_INCLUDE_ASCENDANT );
 	check_objects_meridian->SetValue( config->vObjects & OBJECTS_INCLUDE_MERIDIAN );
-  check_objects_uranian->SetValue( config->vObjects & OBJECTS_INCLUDE_URANIAN );
-  check_objects_chiron->SetValue( config->vObjects & OBJECTS_INCLUDE_CHIRON );
-  check_objects_pholus->SetValue( config->vObjects & OBJECTS_INCLUDE_PHOLUS );
-  check_objects_planetoids->SetValue( config->vObjects & OBJECTS_INCLUDE_PLANETOIDS );
-  check_objects_lilith->SetValue( config->vObjects & OBJECTS_INCLUDE_LILITH );
-  check_objects_upagrahas->SetValue( config->vObjects & OBJECTS_INCLUDE_UPAGRAHAS );
+	check_objects_uranian->SetValue( config->vObjects & OBJECTS_INCLUDE_URANIAN );
+	check_objects_chiron->SetValue( config->vObjects & OBJECTS_INCLUDE_CHIRON );
+	check_objects_pholus->SetValue( config->vObjects & OBJECTS_INCLUDE_PHOLUS );
+	check_objects_planetoids->SetValue( config->vObjects & OBJECTS_INCLUDE_PLANETOIDS );
+	check_objects_lilith->SetValue( config->vObjects & OBJECTS_INCLUDE_LILITH );
+	check_objects_upagrahas->SetValue( config->vObjects & OBJECTS_INCLUDE_UPAGRAHAS );
 	check_objects_kalavelas->SetValue( config->vObjects & OBJECTS_INCLUDE_KALAVELAS );
-  check_objects_lagnas->SetValue( config->vObjects & OBJECTS_INCLUDE_SPECIALLAGNAS );
+	check_objects_lagnas->SetValue( config->vObjects & OBJECTS_INCLUDE_SPECIALLAGNAS );
 	check_objects_d9lagna->SetValue( config->vObjects & OBJECTS_INCLUDE_D9_LAGNA );
 	check_objects_aries->SetValue( config->vObjects & OBJECTS_INCLUDE_ARIES );
 
-  check_objects_house_cusp->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_HOUSES );
+	check_objects_house_cusp->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_HOUSES );
 
 	choice_order_lagna->SetSelection( config->vOrderLagna );
 
 	check_main_declinations->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_DECLINATION );
-  check_main_lords->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_LORD );
-  check_main_dignities->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_DIGNITY );
-  check_main_d9->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_NAVAMSA );
-  check_main_nak->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_NAKSHATRA );
-  check_main_pada->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_PADA );
-  check_main_kp->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_KP );
-  check_main_d60->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_SHASTIAMSA );
-  check_main_d10->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_DASAVARGA );
+	check_main_lords->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_LORD );
+	check_main_dignities->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_DIGNITY );
+	check_main_d9->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_NAVAMSA );
+	check_main_nak->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_NAKSHATRA );
+	check_main_pada->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_PADA );
+	check_main_kp->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_KP );
+	check_main_d60->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_SHASTIAMSA );
+	check_main_d10->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_DASAVARGA );
 	check_main_bhava->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_HOUSEPOS );
-  check_main_kara->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_KARAKA );
-  check_main_ashtaka->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_ASHTAKA );
+	check_main_kara->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_KARAKA );
+	check_main_ashtaka->SetValue( config->vMainChildStyle & MAIN_CHILD_SHOW_ASHTAKA );
+
 	arabicParts = config->vArabicParts;
 	updateArabicText();
 }
 
 /*****************************************************
 **
-**   VedicPanel   ---   saveData 
+**   VedicPanel   ---   saveData
 **
 ******************************************************/
 bool VedicPanel::saveData()
 {
-  config->vObjects = 0;
+	config->vObjects = getMainStyleFromGui();
+
+	config->vArabicParts = arabicParts;
+	if ( arabicParts.Count() > 0 ) config->vObjects |= OBJECTS_INCLUDE_ARABICPARTS;
+
+	config->vOrderLagna = choice_order_lagna->GetSelection();
+
+	config->vMainChildStyle = 0;
+	if ( check_objects_house_cusp->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_HOUSES;
+	if ( check_main_declinations->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_DECLINATION;
+	if ( check_main_lords->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_LORD;
+	if ( check_main_dignities->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_DIGNITY;
+	if ( check_main_d9->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_NAVAMSA;
+	if ( check_main_nak->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_NAKSHATRA;
+	if ( check_main_pada->GetValue()) config->vMainChildStyle  |= MAIN_CHILD_SHOW_PADA;
+	if ( check_main_kp->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_KP;
+	if ( check_main_d60->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_SHASTIAMSA;
+	if ( check_main_d10->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_DASAVARGA;
+	if ( check_main_bhava->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_HOUSEPOS ;
+	if ( check_main_kara->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_KARAKA;
+	if ( check_main_ashtaka->GetValue()) config->vMainChildStyle  |= MAIN_CHILD_SHOW_ASHTAKA;
+	return true;
+}
+
+/*****************************************************
+**
+**   VedicPanel   ---   getMainStyleFromGui
+**
+******************************************************/
+int VedicPanel::getMainStyleFromGui()
+{
+	int style = 0;
 #define SET_CONFIG_OBJECT( a, f ) \
-  a->GetValue() ? config->vObjects |= f :  config->vObjects &= ~f;
+  a->GetValue() ? style |= f :  config->vObjects &= ~f;
 	SET_CONFIG_OBJECT( check_objects_outer, OBJECTS_INCLUDE_OUTER )
 	SET_CONFIG_OBJECT( check_objects_dragonhead, OBJECTS_INCLUDE_DRAGONHEAD )
 	SET_CONFIG_OBJECT( check_objects_dragontail, OBJECTS_INCLUDE_DRAGONTAIL )
@@ -172,30 +203,10 @@ bool VedicPanel::saveData()
 	SET_CONFIG_OBJECT( check_objects_upagrahas, OBJECTS_INCLUDE_UPAGRAHAS )
 	SET_CONFIG_OBJECT( check_objects_kalavelas, OBJECTS_INCLUDE_KALAVELAS )
 	SET_CONFIG_OBJECT( check_objects_lagnas, OBJECTS_INCLUDE_SPECIALLAGNAS )
-	SET_CONFIG_OBJECT( check_objects_d9lagna, OBJECTS_INCLUDE_D9_LAGNA )
 	SET_CONFIG_OBJECT( check_objects_aries, OBJECTS_INCLUDE_ARIES )
+	SET_CONFIG_OBJECT( check_objects_d9lagna, OBJECTS_INCLUDE_D9_LAGNA )
 #undef SET_CONFIG_OBJECT
-
-	config->vArabicParts = arabicParts;
-	if ( arabicParts.Count() > 0 ) config->vObjects |= OBJECTS_INCLUDE_ARABICPARTS;
-
-	config->vOrderLagna = choice_order_lagna->GetSelection();
-
-  config->vMainChildStyle = 0;
- 	if ( check_objects_house_cusp->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_HOUSES;
- 	if ( check_main_declinations->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_DECLINATION;
-  if ( check_main_lords->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_LORD;
-  if ( check_main_dignities->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_DIGNITY;
-  if ( check_main_d9->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_NAVAMSA;
-  if ( check_main_nak->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_NAKSHATRA;
-  if ( check_main_pada->GetValue()) config->vMainChildStyle  |= MAIN_CHILD_SHOW_PADA;
-  if ( check_main_kp->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_KP;
-  if ( check_main_d60->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_SHASTIAMSA;
-  if ( check_main_d10->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_DASAVARGA;
-	if ( check_main_bhava->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_HOUSEPOS ;
-  if ( check_main_kara->GetValue()) config->vMainChildStyle |= MAIN_CHILD_SHOW_KARAKA;
-  if ( check_main_ashtaka->GetValue()) config->vMainChildStyle  |= MAIN_CHILD_SHOW_ASHTAKA;
-	return true;
+	return style;
 }
 
 /*****************************************************
@@ -206,7 +217,7 @@ bool VedicPanel::saveData()
 void VedicPanel::OnArabicParts( wxCommandEvent &event )
 {
 	wxString parts[MAX_ARABIC_OBJECTS];
-	for( unsigned int i = 0; i < MAX_ARABIC_OBJECTS; i++ ) parts[i] = ArabicPartsExpert::getObjectName( FIRST_ARABIC_OBJECT + i, TLARGE );
+	for ( unsigned int i = 0; i < MAX_ARABIC_OBJECTS; i++ ) parts[i] = ArabicPartsExpert::getObjectName( FIRST_ARABIC_OBJECT + i, TLARGE );
 
 	wxMultiChoiceDialog dialog( this,	_( "Choose Arabic Parts" ), GUI_APP_NAME, MAX_ARABIC_OBJECTS, parts );
 	dialog.SetSelections( arabicParts );
@@ -224,22 +235,22 @@ void VedicPanel::updateArabicText()
 	wxString s;
 	if ( arabicParts.size() == 0 )
 	{
-    label_arabic_selection->SetLabel( _( "No part selected" ));
+		label_arabic_selection->SetLabel( _( "No part selected" ));
 	}
 	else if ( arabicParts.size() == 1 )
 	{
-    label_arabic_selection->SetLabel( ArabicPartsExpert::getObjectName( arabicParts[0] + FIRST_ARABIC_OBJECT, TLARGE ));
+		label_arabic_selection->SetLabel( ArabicPartsExpert::getObjectName( arabicParts[0] + FIRST_ARABIC_OBJECT, TLARGE ));
 	}
 	else
 	{
 		s.Printf( _( "%d parts selected" ), arabicParts.size());
-    label_arabic_selection->SetLabel( s );
+		label_arabic_selection->SetLabel( s );
 	}
 }
 
 /*****************************************************
 **
-**   VedicPanel   ---   set_properties 
+**   VedicPanel   ---   set_properties
 **
 ******************************************************/
 void VedicPanel::set_properties()
@@ -278,7 +289,7 @@ void VedicPanel::set_properties()
 
 /*****************************************************
 **
-**   VedicPanel   ---   do_layout 
+**   VedicPanel   ---   do_layout
 **
 ******************************************************/
 void VedicPanel::do_layout()
@@ -288,7 +299,7 @@ void VedicPanel::do_layout()
     wxFlexGridSizer* sizer_right = new wxFlexGridSizer(2, 1, 0, 0);
     wxStaticBoxSizer* sizer_maincols = new wxStaticBoxSizer(sizer_maincols_staticbox, wxVERTICAL);
     wxFlexGridSizer* grid_maincols = new wxFlexGridSizer(11, 1, 3, 0);
-    wxFlexGridSizer* sizer_center = new wxFlexGridSizer(2, 1, 0, 0);
+    wxFlexGridSizer* sizer_center = new wxFlexGridSizer(3, 1, 0, 0);
     wxStaticBoxSizer* sizer_order_lagna = new wxStaticBoxSizer(sizer_order_lagna_staticbox, wxVERTICAL);
     wxStaticBoxSizer* sizer_arabic = new wxStaticBoxSizer(sizer_arabic_staticbox, wxVERTICAL);
     wxBoxSizer* sizer_arabic_selection = new wxBoxSizer(wxHORIZONTAL);
@@ -355,3 +366,13 @@ void VedicPanel::do_layout()
     // end wxGlade
 }
 
+/*****************************************************
+**
+**   ConfigPanelFactory   ---   createVedicPanel
+**
+******************************************************/
+ConfigPanel *ConfigPanelFactory::createVedicPanel( wxWindow *parent )
+{
+	return new VedicPanel( parent );
+}
+
