@@ -3,9 +3,9 @@
  *  for Vedic and western astrology.
 
  *  File       src/gui/ApplicationWindow.cpp
- *  Release    6.0
- *  Author     M. Pettau
- *  Copyright  2003-2010 by the author
+ *  Release    7.0
+ *  Author     Martin Pettau
+ *  Copyright  2003-2012 by the author
 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -19,7 +19,7 @@
 ****************************************************************************/
 
 #ifdef __GNUG__
-	#pragma implementation "ApplicationWindow.h"
+#pragma implementation "ApplicationWindow.h"
 #endif
 
 #include "ApplicationWindow.h"
@@ -36,8 +36,10 @@
 #include <wx/mimetype.h>
 #include <wx/log.h>
 #include <wx/sizer.h>
+#include <wx/sysopt.h>
 #include <wx/textctrl.h>
 
+#include "AtlasDialog.h"
 #include "ChildWindow.h"
 #include "Document.h"
 #include "IconProvider.h"
@@ -49,7 +51,6 @@
 
 #include "AboutDialog.h"
 #include "ConfigDialog.h"
-#include "LocationDialog.h"
 
 #include "constants.h"
 #include "Calculator.h"
@@ -69,7 +70,7 @@ IMPLEMENT_CLASS( ApplicationWindow, wxFrame )
 **
 ******************************************************/
 MaitreyaApp::MaitreyaApp()
- : wxApp()
+		: wxApp()
 {
 }
 
@@ -88,7 +89,15 @@ bool MaitreyaApp::OnInit()
 	SetVendorName( VENDOR_NAME );
 
 	s = wxT( "." );
-#ifndef __WXMSW__
+
+#if defined( __WXMSW__)
+
+	// Nothing to do
+
+#elif defined( __WXMAC__ )
+	wxSystemOptions::SetOption( wxT( "mac.listctrl.always_use_generic" ), 1 );
+	s = MAC_RESOURCE_DIRECTORY;
+#else  // Gtk, universal, expecting parameter for data directory
 	if ( argc <= 1 )
 	{
 		printf( "WARN: missing parameter for datadir, assuming '..'\n" );
@@ -109,9 +118,9 @@ bool MaitreyaApp::OnInit()
 	*/
 	wxDisplaySize( &screenx, &screeny );
 	if ( config->xMasterWindow <= 0 || config->xMasterWindow > screenx
-		|| config->yMasterWindow <= 0 || config->yMasterWindow > screeny
-		|| config->xPosMasterWindow <= 0 || config->xPosMasterWindow > screenx
-		|| config->yPosMasterWindow <= 0 || config->yPosMasterWindow > screeny )
+	        || config->yMasterWindow <= 0 || config->yMasterWindow > screeny
+	        || config->xPosMasterWindow <= 0 || config->xPosMasterWindow > screenx
+	        || config->yPosMasterWindow <= 0 || config->yPosMasterWindow > screeny )
 	{
 		// Set default coordinates
 		config->xMasterWindow = 720;
@@ -120,14 +129,16 @@ bool MaitreyaApp::OnInit()
 		config->yPosMasterWindow = 50;
 	}
 	frame = new ApplicationWindow( GUI_APP_NAME, config->xPosMasterWindow, config->yPosMasterWindow,
-		config->xMasterWindow, config->yMasterWindow );
+	                               config->xMasterWindow, config->yMasterWindow );
 
 	frame->Show( true );
-  //SetTopWindow(frame);
+	//SetTopWindow(frame);
 
 	if ( argc <= startarg )
-		{ if ( config->openNewDocOnStart ) frame->NewFile( config->useMultipleViews, -1 ); }
-	for( int i = startarg; i < argc; i++ )
+	{
+		if ( config->openNewDocOnStart ) frame->NewFile( config->useMultipleViews, -1 );
+	}
+	for ( int i = startarg; i < argc; i++ )
 	{
 		frame->OpenFile( argv[i] );
 	}
@@ -154,7 +165,7 @@ int MaitreyaApp::OnExit()
 **
 ******************************************************/
 ApplicationWindow::ApplicationWindow(const wxChar *title, int xpos, int ypos, int width, int height)
-	: wxFrame( 0, -1, title, wxPoint(xpos, ypos), wxSize(width, height))
+		: wxFrame( 0, -1, title, wxPoint(xpos, ypos), wxSize(width, height))
 {
 	wxString rfiles, s;
 
@@ -164,7 +175,7 @@ ApplicationWindow::ApplicationWindow(const wxChar *title, int xpos, int ypos, in
 	if ( config->logMode == 1 )
 	{
 		m_text = new wxTextCtrl(this, wxID_ANY, wxT("Log window.\n"),
-			wxPoint(0, 250), wxSize(100, 150), wxTE_MULTILINE);
+		                        wxPoint(0, 250), wxSize(100, 150), wxTE_MULTILINE);
 		m_logTargetOld = wxLog::SetActiveTarget(new wxLogTextCtrl(m_text));
 		wxBoxSizer* sizer = new wxBoxSizer( wxVERTICAL );
 		sizer->Add( listctrl, 1, wxEXPAND | wxALL, 3 );
@@ -197,34 +208,39 @@ ApplicationWindow::ApplicationWindow(const wxChar *title, int xpos, int ypos, in
 	statusbar = (MainWindowStatusbar*)CreateStatusBar();
 	showStatusBar();
 
-  Connect( CMD_CHILD_FIRST+1, CMD_CHILD_GRAPHIC_STYLE+30, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnChildCommand ));
-  Connect( APP_FILENEW, APP_FILE_NEW_MULTIPLE + 100, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnFileNew ));
-  Connect( APP_FILEOPEN, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnFileOpen ));
-  Connect( APP_FILEQUIT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnFileQuit ));
-  Connect( APP_SHOWSTATUSBAR, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnToggleStatusBar ));
-  Connect( APP_SHOWMAINTOOLBAR, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnToggleToolBars ));
-  Connect( APP_SAVECONFIG, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnSaveConfig ));
-  Connect( APP_CONFIGURE, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnConfigure ));
-  Connect( APP_LOCATION, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnLocationDialog ));
-  Connect( APP_ABOUT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnAppAbout ));
-  Connect( APP_HELP, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnAppHelp ));
+#if defined( __WXMAC__ )
+	// Otherwise window will grow on each startup
+	SetSize( width, height );
+#endif
 
-  Connect( APP_LIST_BIGICONS, APP_LIST_TABLE, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnToggleIcons ));
-  Connect( APP_SHOWHORA, APP_SHOWEPHEM, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnNewChild ));
-  Connect( APP_FILERECENT, APP_FILERECENT+35, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnOpenRecent ));
+	Connect( CMD_CHILD_FIRST+1, CMD_CHILD_GRAPHIC_STYLE+30, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnChildCommand ));
+	Connect( APP_FILENEW, APP_FILE_NEW_MULTIPLE + 100, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnFileNew ));
+	Connect( APP_FILEOPEN, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnFileOpen ));
+	Connect( APP_FILEQUIT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnFileQuit ));
+	Connect( APP_SHOWSTATUSBAR, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnToggleStatusBar ));
+	Connect( APP_SHOWMAINTOOLBAR, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnToggleToolBars ));
+	Connect( APP_SAVECONFIG, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnSaveConfig ));
+	Connect( APP_CONFIGURE, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnConfigure ));
+	Connect( APP_LOCATION, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnLocationDialog ));
+	Connect( APP_ABOUT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnAppAbout ));
+	Connect( APP_HELP, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnAppHelp ));
 
-  Connect( wxID_ANY, CONFIG_CHANGED, wxCommandEventHandler( ApplicationWindow::OnConfigChanged ));
-  Connect( wxID_ANY, CONFIG_TOOLBAR_CHANGED, wxCommandEventHandler( ApplicationWindow::OnToolbarConfigChanged ));
-  Connect( wxID_ANY, CHILD_SETACTIVE, wxCommandEventHandler( ApplicationWindow::OnChildFocusEvent ));
-  Connect( wxID_ANY, CHILD_CLOSED, wxCommandEventHandler( ApplicationWindow::OnChildCloseEvent ));
-  Connect( wxID_ANY, CREATE_ENTRY_CHART, wxCommandEventHandler( ApplicationWindow::OnCreateEntryChart ));
-  Connect( wxID_ANY, DOC_SAVED, wxCommandEventHandler( ApplicationWindow::OnDocSavedEvent ));
-  Connect( wxID_ANY, DOC_UPDATED, wxCommandEventHandler( ApplicationWindow::OnDocUpdateEvent ));
+	Connect( APP_LIST_BIGICONS, APP_LIST_TABLE, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnToggleIcons ));
+	Connect( APP_SHOWHORA, APP_SHOWEPHEM, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnNewChild ));
+	Connect( APP_FILERECENT, APP_FILERECENT+35, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ApplicationWindow::OnOpenRecent ));
 
-  Connect( wxEVT_CLOSE_WINDOW, wxCloseEventHandler( ApplicationWindow::OnClose ));
-  Connect( wxEVT_DROP_FILES, wxDropFilesEventHandler( ApplicationWindow::OnDropFilesEvent ));
-  Connect( LISTCTRL_ID, wxEVT_COMMAND_LIST_ITEM_SELECTED, wxListEventHandler( ApplicationWindow::OnListItemSelected ));
-  Connect( wxEVT_IDLE, wxIdleEventHandler( ApplicationWindow::OnIdle ));
+	Connect( wxID_ANY, CONFIG_CHANGED, wxCommandEventHandler( ApplicationWindow::OnConfigChanged ));
+	Connect( wxID_ANY, CONFIG_TOOLBAR_CHANGED, wxCommandEventHandler( ApplicationWindow::OnToolbarConfigChanged ));
+	Connect( wxID_ANY, CHILD_SETACTIVE, wxCommandEventHandler( ApplicationWindow::OnChildFocusEvent ));
+	Connect( wxID_ANY, CHILD_CLOSED, wxCommandEventHandler( ApplicationWindow::OnChildCloseEvent ));
+	Connect( wxID_ANY, CREATE_ENTRY_CHART, wxCommandEventHandler( ApplicationWindow::OnCreateEntryChart ));
+	Connect( wxID_ANY, DOC_SAVED, wxCommandEventHandler( ApplicationWindow::OnDocSavedEvent ));
+	Connect( wxID_ANY, DOC_UPDATED, wxCommandEventHandler( ApplicationWindow::OnDocUpdateEvent ));
+
+	Connect( wxEVT_CLOSE_WINDOW, wxCloseEventHandler( ApplicationWindow::OnClose ));
+	Connect( wxEVT_DROP_FILES, wxDropFilesEventHandler( ApplicationWindow::OnDropFilesEvent ));
+	Connect( LISTCTRL_ID, wxEVT_COMMAND_LIST_ITEM_SELECTED, wxListEventHandler( ApplicationWindow::OnListItemSelected ));
+	Connect( wxEVT_IDLE, wxIdleEventHandler( ApplicationWindow::OnIdle ));
 
 	updateTools = true;
 }
@@ -262,7 +278,7 @@ void ApplicationWindow::SetActiveChild( ChildWindow *child )
 {
 	updateTools = true;
 	if ( ! listctrl->getNumberOfEntries() ) return;
-	for( long i = 0; i < listctrl->getNumberOfEntries(); i++ )
+	for ( long i = 0; i < listctrl->getNumberOfEntries(); i++ )
 	{
 		if ( listctrl->getChild(i) == child )
 		{
@@ -305,7 +321,7 @@ void ApplicationWindow::OnIdle( wxIdleEvent &event )
 ******************************************************/
 void ApplicationWindow::OnChildClose( ChildWindow *child )
 {
-  listctrl->deleteEntry( child );
+	listctrl->deleteEntry( child );
 	Document *doc = child->getDoc();
 
 	//printf( "ApplicationWindow::OnChildClose\n" );
@@ -328,18 +344,18 @@ void ApplicationWindow::OnFileNew( wxCommandEvent &event )
 	bool useMultipleView = config->useMultipleViews;
 	switch ( event.GetId() )
 	{
-		case APP_FILENEW:
+	case APP_FILENEW:
 		break;
-		case APP_FILE_NEW_SIMPLE:
-			useMultipleView = false;
+	case APP_FILE_NEW_SIMPLE:
+		useMultipleView = false;
 		break;
-		case APP_FILE_NEW_MULTIPLE_DEFAULT:
-			useMultipleView = true;
-			viewId = -1;
+	case APP_FILE_NEW_MULTIPLE_DEFAULT:
+		useMultipleView = true;
+		viewId = -1;
 		break;
-		default:
-			useMultipleView = true;
-			viewId = event.GetId() - APP_FILE_NEW_MULTIPLE;
+	default:
+		useMultipleView = true;
+		viewId = event.GetId() - APP_FILE_NEW_MULTIPLE;
 		break;
 	}
 	NewFile( useMultipleView, viewId );
@@ -371,12 +387,14 @@ void ApplicationWindow::OnFileOpen( wxCommandEvent &event )
 {
 	wxString filetypes = wxT( "Maitreya (*.mtx)|*.mtx| Maitreya 2.x (*.atx)|*.atx|Jagannatha Hora (*.jhd)|*.jhd| All files (*.*)|*.*" );
 	wxFileDialog openFileDialog( this, _( "Open file"), config->defOpenPath, wxT( "" ),
-		filetypes, wxFD_OPEN, wxDefaultPosition );
+	                             filetypes, wxFD_OPEN, wxDefaultPosition );
 
 	openFileDialog.SetFilterIndex( config->defOpenFiletype );
 	if (openFileDialog.ShowModal() == wxID_OK )
 	{
-		if ( OpenFile( openFileDialog.GetDirectory() + wxFileName::GetPathSeparator()  + openFileDialog.GetFilename() ))
+		// Bugfix 7.0.3 GetDirectory returns home directory on some Linux distros instead of selected dir
+		//if ( OpenFile( openFileDialog.GetDirectory() + wxFileName::GetPathSeparator()  + openFileDialog.GetFilename() ))
+		if ( OpenFile( openFileDialog.GetPath() ))
 		{
 			config->defOpenPath = openFileDialog.GetDirectory();
 			config->defOpenFiletype = openFileDialog.GetFilterIndex();
@@ -399,8 +417,8 @@ bool ApplicationWindow::OpenFile( wxString filename )
 	{
 		delete doc;
 		doMessageBox( this,
-			wxString::Format( wxT( "%s %s" ), _( "Cannot open file" ), (const wxChar*)filename ),
-			wxOK | wxICON_ERROR );
+		              wxString::Format( wxT( "%s %s" ), _( "Cannot open file" ), (const wxChar*)filename ),
+		              wxOK | wxICON_ERROR );
 		return false;
 	}
 	menubar->addToRecentFiles( filename );
@@ -463,13 +481,13 @@ void ApplicationWindow::OnNewChild( wxCommandEvent &event )
 	//printf( "ApplicationWindow::OnNewChild %d\n", event.GetId() );
 	ChildWindowFactory factory;
 
-	switch( event.GetId() )
+	switch ( event.GetId() )
 	{
-		case APP_NEW_PARTNER:
-			child = factory.createPartnerWindow( this, docmanager );
+	case APP_NEW_PARTNER:
+		child = factory.createPartnerWindow( this, docmanager );
 		break;
-		default:
-			child = factory.createChild( this, 0, event.GetId(), true );
+	default:
+		child = factory.createChild( this, 0, event.GetId(), true );
 		break;
 	}
 	AddChild( child );
@@ -485,7 +503,7 @@ void ApplicationWindow::OnChildCommand( wxCommandEvent &event )
 {
 	updateTools = true;
 	int id = event.GetId();
-	wxLogMessage( wxT( "ApplicationWindow::OnChildCommand %d" ), id );
+	//printf( "ApplicationWindow::OnChildCommand %d object %ld\n", id, (long)event.GetEventObject() );
 	if ( ! docommands ) return;
 	ChildWindow *child = listctrl->getActiveChild();
 
@@ -503,10 +521,10 @@ void ApplicationWindow::OnChildCommand( wxCommandEvent &event )
 	{
 		// avoid that document dependent view is opened based upon non doc view, ugly but works
 		if ( child->getDoc() == 0 &&
-		( id == CMD_CHILD_NEW_TEXT || id == CMD_CHILD_NEW_TRANSIT || id == CMD_CHILD_NEW_SBC || id == CMD_CHILD_NEW_SOLAR
-			|| id == CMD_CHILD_NEW_YOGA || id == CMD_CHILD_NEW_GRAPHICALDASA || id == CMD_CHILD_NEW_DASA
-			|| id == CMD_CHILD_NEW_URANIAN || id == CMD_CHILD_NEW_WCHART || id == CMD_CHILD_NEW_MAINVIEW
-			|| id >= CMD_CHILD_NEW_RASI )) return;
+		        ( id == CMD_CHILD_NEW_TEXT || id == CMD_CHILD_NEW_TRANSIT || id == CMD_CHILD_NEW_SBC || id == CMD_CHILD_NEW_SOLAR
+		          || id == CMD_CHILD_NEW_YOGA || id == CMD_CHILD_NEW_GRAPHICALDASA || id == CMD_CHILD_NEW_DASA
+		          || id == CMD_CHILD_NEW_URANIAN || id == CMD_CHILD_NEW_WCHART || id == CMD_CHILD_NEW_MAINVIEW
+		          || id >= CMD_CHILD_NEW_RASI )) return;
 
 		// may be done now
 		AddChild( ChildWindowFactory().createChild( this, child->getDoc(), id, true ));
@@ -550,12 +568,12 @@ void ApplicationWindow::OnClose( wxCloseEvent &event )
 	}
 	wxLogMessage( wxT( "ApplicationWindow::OnClose -- Closing" ));
 
-	for( i = 0; i < docmanager->getNbDocuments(); i++ )
+	for ( i = 0; i < docmanager->getNbDocuments(); i++ )
 	{
 		doc = docmanager->getDocument( i );
 		if ( ! doc->queryClose() ) return;
 	}
-	for( i = 0; i < listctrl->getNumberOfEntries(); i++ )
+	for ( i = 0; i < listctrl->getNumberOfEntries(); i++ )
 	{
 		if ( ! listctrl->getChild( i )->Close()) return;
 	}
@@ -606,8 +624,8 @@ void ApplicationWindow::OnConfigure( wxCommandEvent &event )
 ******************************************************/
 void ApplicationWindow::OnLocationDialog( wxCommandEvent &event )
 {
-  LocationDialog dialog( this, 0 );
-	dialog.ShowModal();
+	AtlasDialogWrapper wrapper( this, ATLASDIALOG_CALLER_APPLICATIONWINDOW );
+	wrapper.run();
 	updateTools = true;
 }
 
@@ -680,13 +698,13 @@ void ApplicationWindow::OnToggleStatusBar( wxCommandEvent &event )
 ******************************************************/
 void ApplicationWindow::OnToggleToolBars( wxCommandEvent &event )
 {
-	switch( event.GetId() )
+	switch ( event.GetId() )
 	{
-		case APP_SHOWMAINTOOLBAR:
-			config->showMainToolbar = event.IsChecked();
+	case APP_SHOWMAINTOOLBAR:
+		config->showMainToolbar = event.IsChecked();
 		break;
-		default:
-			assert( 0 );
+	default:
+		assert( 0 );
 		break;
 	}
 	showToolBars();
@@ -717,7 +735,7 @@ void ApplicationWindow::showToolBars()
 void ApplicationWindow::OnDropFilesEvent( wxDropFilesEvent &event )
 {
 	wxLogMessage( wxT( "ApplicationWindow::OnDropFilesEvent" ));
-	for( int i = 0; i < event.GetNumberOfFiles(); i++ )
+	for ( int i = 0; i < event.GetNumberOfFiles(); i++ )
 	{
 		wxLogMessage( wxT( "ApplicationWindow::OnDropFilesEvent open %s"), (const wxChar*)((event.GetFiles())[i]) );
 		OpenFile( (const wxChar*)((event.GetFiles())[i]) );
@@ -754,7 +772,7 @@ void ApplicationWindow::OnConfigChanged( wxCommandEvent &event )
 	calculator->init();
 	wxString oldcfg = config->mainToolbarItems;
 	wxString tb = config->mainToolbarItems;
-	for( i = 0; i < docmanager->getNbDocuments(); i++ )
+	for ( i = 0; i < docmanager->getNbDocuments(); i++ )
 	{
 		doc = docmanager->getDocument( i );
 		if ( doc )
@@ -763,6 +781,7 @@ void ApplicationWindow::OnConfigChanged( wxCommandEvent &event )
 			doc->updateAllChildWindows();
 		}
 	}
+	listctrl->onConfigChanged();
 	if ( config->showStatusBar )
 		((MainWindowStatusbar*)GetStatusBar())->StartPlanetTimer( config->showStatusInfo );
 	updateTools = true;
