@@ -3,9 +3,9 @@
  *  for Vedic and western astrology.
 
  *  File       src/gui/ToolPanel.cpp
- *  Release    6.0
- *  Author     M. Pettau
- *  Copyright  2003-2010 by the author
+ *  Release    7.0
+ *  Author     Martin Pettau
+ *  Copyright  2003-2012 by the author
 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -19,7 +19,7 @@
 ****************************************************************************/
 
 #ifdef __GNUG__
-	#pragma implementation "ToolPanel.h"
+#pragma implementation "ToolPanel.h"
 #endif
 
 #include "ToolPanel.h"
@@ -54,12 +54,13 @@ extern Config *config;
 
 /*****************************************************
 **
-**   MaitreyaToolbar   ---   Constructor 
+**   MaitreyaToolbar   ---   Constructor
 **
 ******************************************************/
 MaitreyaToolbar::MaitreyaToolbar( wxWindow* parent )
- : wxToolBar( parent, -1, wxDefaultPosition, wxDefaultSize, TB_STYLE )
+		: wxToolBar( parent, -1, wxDefaultPosition, wxDefaultSize, TB_STYLE )
 {
+	//Connect( wxEVT_CHAR, wxKeyEventHandler( MaitreyaToolbar::OnChar ));
 }
 
 /*****************************************************
@@ -70,27 +71,46 @@ MaitreyaToolbar::MaitreyaToolbar( wxWindow* parent )
 void MaitreyaToolbar::recreate()
 {
 	ToolbarFactory *factory = ToolbarFactory::get();
-	vector<ToolBarCommand> cmdlist = factory->getUsedCommandList();
 	ClearTools();
- 
+
+	vector<ToolBarCommand> commands;
+	if ( config->mainToolbarItems.IsEmpty())
+	{
+		commands = factory->getDefaultCommandList();
+	}
+	else
+	{
+		commands = factory->getCommandListFromString( config->mainToolbarItems );
+	}
+
 	// params
 	SetToolBitmapSize( wxSize( 24, 24 ));
-	for( unsigned int i = 0; i < cmdlist.size(); i++ )
+	for ( unsigned int i = 0; i < commands.size(); i++ )
 	{
-		if ( cmdlist[i].commandId != 0 )
-			AddTool( cmdlist[i].commandId, cmdlist[i].description, IconProvider::getBitmap( cmdlist[i].bitmapId ), cmdlist[i].description );
+		if ( commands[i].commandId != 0 )
+			AddTool( commands[i].commandId, commands[i].description, IconProvider::getBitmap( commands[i].bitmapId ), commands[i].description );
 		else AddSeparator();
 	}
 }
 
 /*****************************************************
 **
-**   MaitreyaToolbar   ---   updateTools 
+**   MaitreyaToolbar   ---   OnChar
+**
+******************************************************/
+void MaitreyaToolbar::OnChar( wxKeyEvent &event )
+{
+	printf( "Toolbar ONCHAR %d control %d\n", event.GetKeyCode(), event.m_controlDown );
+}
+
+/*****************************************************
+**
+**   MaitreyaToolbar   ---   updateTools
 **
 ******************************************************/
 void MaitreyaToolbar::updateTools( const bool &isDoc )
 {
-	for( int i = CMD_CHILD_FIRST + 1; i < CMD_CHILD_LAST; i++ ) EnableTool( i, isDoc );
+	for ( int i = CMD_CHILD_FIRST + 1; i < CMD_CHILD_LAST; i++ ) EnableTool( i, isDoc );
 }
 
 
@@ -99,17 +119,20 @@ void MaitreyaToolbar::updateTools( const bool &isDoc )
 **   TOOLBAR DEFINITIONS
 **
 ******************************************************/
-const int tb_horawindow[] = { TBB_NOW, TBS_DATE, -1 };
+const int tb_horawindow[] = { TBS_DATE, TBB_NOW, TBS_TZ, -1 };
 const int tb_textwindow[] = { TBS_TEXTMODE, TBS_VARGA, TBS_DASA, -1 };
 const int tb_ashtakavargawindow[] = { TBS_VARGA, -1 };
-const int tb_eclipsewindow[] = { TBS_YEAR, TBS_NBYEARS, TBS_ECL_TYPE, TBS_EPHEMTZ, -1 };
-const int tb_transitwindow[] = { TBS_DATE, TBS_TIME, TBB_NOW, TBS_DATE_PROGRESS, TB_SEPARATOR, TBS_TRANSITMODE, TBS_YEARLENGTH,
-	TBS_SORT, TBS_ORBIS, TBS_CIRCLETYPE, -1 };
+const int tb_eclipsewindow[] = { TBS_YEAR, TBS_NBYEARS, TBS_ECL_TYPE, TBS_TZ, -1 };
+const int tb_transitwindow[] = { TBS_DATE, TBS_TIME, TBB_NOW, TBS_TZ, TBS_DATE_PROGRESS, TB_SEPARATOR, TBS_TRANSITMODE, TBS_YEARLENGTH,
+                                 TBS_SORT, TBS_ORBIS, TBS_CIRCLETYPE, -1
+                               };
 const int tb_uranianwindow[] = { TBS_URANIANMODE, TBS_SORT, TBS_FILTER, TBS_ORBIS, TBS_CIRCLETYPE,
-	TBS_YEAR, TBS_YEARLENGTH, -1 };
+                                 TBS_YEAR, TBS_YEARLENGTH, -1
+                               };
 const int tb_gdasawindow[] = { TBB_GOTO, TBB_NOW, TBB_DASA, TB_SEPARATOR, TBS_ZOOM, TBS_ANTARDASALEVEL, TB_TEXT, -1 };
-const int tb_ephemwindow[] = { TBS_YEAR, TBS_MONTH, TBB_NOW, TB_SEPARATOR, TBS_EPHEMMODE, TBS_EPHEMTZ, TBS_DASA,
-	TBS_EPHEMDEG, -1 };
+const int tb_ephemwindow[] = { TBS_YEAR, TBS_MONTH, TBB_NOW, TB_SEPARATOR, TBS_EPHEMMODE, TBS_TZ, TBS_DASA,
+                               TBS_EPHEMDEG, -1
+                             };
 const int tb_solarwindow[] = { TBS_YEAR, TBB_NOW, TBB_NEW, TB_TEXT, -1 };
 const int tb_partnerwindow[] = { TBS_PARTNER1 , TBS_PARTNER2, TBS_ORBIS, TBS_SORT, TBS_FILTER, TBS_CIRCLETYPE, -1 };
 
@@ -149,47 +172,47 @@ ToolbarFactory *ToolbarFactory::get()
 wxToolBar *ToolbarFactory::createToolbar( wxWindow *parent, const int &type )
 {
 	toolbar = new wxToolBar( parent, -1, wxDefaultPosition, wxDefaultSize, TB_STYLE );
-  toolbar->SetToolBitmapSize( wxSize( 24, 24 ));
-  toolbar->SetMargins( 0, 0 );
-  toolbar->SetToolSeparation( 0 );
+	toolbar->SetToolBitmapSize( wxSize( 24, 24 ));
+	toolbar->SetMargins( 0, 0 );
+	toolbar->SetToolSeparation( 0 );
 	const int *a = 0;
-	switch( type )
+	switch ( type )
 	{
-		case VIEW_URANIAN:
-			a = tb_uranianwindow;
+	case VIEW_URANIAN:
+		a = tb_uranianwindow;
 		break;
-		case VIEW_TRANSIT:
-			a = tb_transitwindow;
+	case VIEW_TRANSIT:
+		a = tb_transitwindow;
 		break;
-		case VIEW_HORA:
-			a = tb_horawindow;
+	case VIEW_HORA:
+		a = tb_horawindow;
 		break;
-		case VIEW_TEXT:
-			a = tb_textwindow;
+	case VIEW_TEXT:
+		a = tb_textwindow;
 		break;
-		case VIEW_ASHTAKAVARGA:
-			a = tb_ashtakavargawindow;
+	case VIEW_ASHTAKAVARGA:
+		a = tb_ashtakavargawindow;
 		break;
-		case VIEW_SOLAR:
-			a = tb_solarwindow;
+	case VIEW_SOLAR:
+		a = tb_solarwindow;
 		break;
-		case VIEW_YOGA:
-			a = tb_yogawindow;
+	case VIEW_YOGA:
+		a = tb_yogawindow;
 		break;
-		case VIEW_YOGA_EDITOR:
-			a = tb_yogaeditor;
+	case VIEW_YOGA_EDITOR:
+		a = tb_yogaeditor;
 		break;
-		case VIEW_GRAPHICALDASA:
-			a = tb_gdasawindow;
+	case VIEW_GRAPHICALDASA:
+		a = tb_gdasawindow;
 		break;
-		case VIEW_ECLIPSE:
-			a = tb_eclipsewindow;
+	case VIEW_ECLIPSE:
+		a = tb_eclipsewindow;
 		break;
-		case VIEW_EPHEM:
-			a = tb_ephemwindow;
+	case VIEW_EPHEM:
+		a = tb_ephemwindow;
 		break;
-		case VIEW_PARTNER:
-			a = tb_partnerwindow;
+	case VIEW_PARTNER:
+		a = tb_partnerwindow;
 		break;
 	}
 	if ( a ) create( a );
@@ -206,7 +229,7 @@ wxToolBar *ToolbarFactory::createToolbar( wxWindow *parent, const int &type )
 void ToolbarFactory::create( const int *a )
 {
 	const int *i = a; // a is int array
-	while( *i != -1 )
+	while ( *i != -1 )
 	{
 		if ( *i < TBS_LAST ) createChoiceItem( *i );
 		else if ( *i == TB_SEPARATOR ) toolbar->AddSeparator();
@@ -243,6 +266,7 @@ void ToolbarFactory::createChoiceItem( const int &item )
 		_("Astronomical"),
 		_("Bhava"),
 		_("Dasa (Short)"),
+		_("Dasa (Compact)"),
 		_("Dasa (Long)"),
 		_("Jaimini"),
 		_("Krishnamurti Paddhati"),
@@ -255,149 +279,152 @@ void ToolbarFactory::createChoiceItem( const int &item )
 	};
 	const static wxString eclipse_types[] = { _("All"), _("Solar"), _("Lunar") };
 	const static wxString uranian_viewmodes[] = { _("Midpoint Summary"), _("Yearly Preview") };
-	const static wxString zoom_choices[] = { wxT("10%"), wxT("25%"), wxT("50%"), wxT("100%"), wxT("150%"), wxT("200%"),
-		wxT("250%"), wxT("300%"), wxT("400%"), wxT("500%") };
+	const static wxString zoom_choices[] = { wxT("10%"), wxT("25%"), wxT("50%"), wxT("100%"),
+		wxT("150%"), wxT("200%"), wxT("250%"), wxT("300%"), wxT("400%"), wxT("500%")
+	                                       };
 	const static wxString antardasa_choices[] = { wxT("Mahadasa"), wxT("Antardasa"), wxT("Pratyantardasa") };
-	const static wxString ephem_mode_choices[] = { _("Default"), _("Graphical"), _("Sunrise/Tithi"), _("Ingress"),
-		_( "Lunar" ), _("KP") };
-	const static wxString ephemtz_choices[] = { _("UT"), _("Local") };
-	const static wxString ephemdeg_choices[] = { wxT("360"), wxT("180"), wxT("90"), wxT("45"), wxT("30"), wxT("22:30"),
-			wxT("13:20"), wxT("11:15"), wxT("5:07:30") };
+	const static wxString ephem_mode_choices[] = { _("Default"), _("Graphical"), _("Sunrise/Tithi"),
+		_("Ingress"), _( "Lunar" ), _("KP")
+	                                             };
+	const static wxString tz_choices[] = { wxT("UTC"), _("Local") };
+	const static wxString ephemdeg_choices[] = { wxT("360"), wxT("180"), wxT("90"), wxT("45"), wxT("30"),
+		wxT("22:30"), wxT("13:20"), wxT("11:15"), wxT("5:07:30")
+	                                           };
 	const static wxString first_house_choices[] = { _("Ascendant"), _("Moon"), _("Arudha Lagna"),
-		_( "Aries" ), _( "Taurus" ), _( "Gemini" ), _( "Cancer" ), _( "Leo" ), _( "Virgo" ),
-		_( "Libra" ), _( "Scorpio" ), _( "Sagittarius" ), _( "Capricorn" ), _( "Aquarius" ), _( "Pisces" )};
+		_( "Aries" ), _( "Taurus" ), _( "Gemini" ), _( "Cancer" ), _( "Leo" ), _( "Virgo" ), _( "Libra" ),
+		_( "Scorpio" ), _( "Sagittarius" ), _( "Capricorn" ), _( "Aquarius" ), _( "Pisces" ) };
 
 	wxChoice *choice = 0;
 	wxControl *control = 0;
 	wxString s;
-	switch( item )
+	switch ( item )
 	{
-		case TBS_TEXTMODE:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 15, text_viewmodes, 0 );
-			choice->SetToolTip( _( "Mode" ));
+	case TBS_TEXTMODE:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 16, text_viewmodes, 0 );
+		choice->SetToolTip( _( "Mode" ));
 		break;
-		case TBS_VARGA:
-			{
-				VargaExpert vexpert;
-				choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
-				for( int i = 0; i < NB_VARGAS; i++ )
-				{
-					if ( vexpert.getVargaDivision(i) > 0 )
-						s.Printf( wxT( "%s (D%d)" ), vexpert.getVargaName(i), vexpert.getVargaDivision(i) );
-					else s = vexpert.getVargaName(i);
-					choice->Append( s );
-				}
-				choice->SetToolTip( _( "Varga" ));
-			}
+	case TBS_VARGA:
+	{
+		VargaExpert vexpert;
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
+		for ( int i = 0; i < NB_VARGAS; i++ )
+		{
+			if ( vexpert.getVargaDivision(i) > 0 )
+				s.Printf( wxT( "%s (D%d)" ), vexpert.getVargaName(i), vexpert.getVargaDivision(i) );
+			else s = vexpert.getVargaName(i);
+			choice->Append( s );
+		}
+		choice->SetToolTip( _( "Varga" ));
+	}
+	break;
+	case TBS_DASA:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
+		for ( unsigned int i = 0; i < DasaExpertFactory::MAX_DASAEXPERTS; i++ )
+			choice->Append( DasaExpertFactory::get()->getDasaExpert(i)->getName() );
+		choice->SetToolTip( _( "Dasa" ));
 		break;
-		case TBS_DASA:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
-			for( unsigned int i = 0; i < DasaExpertFactory::MAX_DASAEXPERTS; i++ )
-				choice->Append( DasaExpertFactory::get()->getDasaExpert(i)->getName() );
-			choice->SetToolTip( _( "Dasa" ));
+	case TBS_YEAR:
+		control = new wxSpinCtrl( toolbar, item, wxT(""), wxDefaultPosition, wxDefaultSize,
+		                          wxSP_ARROW_KEYS | wxTAB_TRAVERSAL, 0, 3000);
+		control->SetSize( 80, control->GetBestSize().GetY());
+		control->SetToolTip( _( "Year" ));
 		break;
-		case TBS_YEAR:
-			control = new wxSpinCtrl( toolbar, item, wxT(""), wxDefaultPosition, wxDefaultSize,
-				wxSP_ARROW_KEYS | wxTAB_TRAVERSAL, 0, 3000);
-			control->SetSize( 80, control->GetBestSize().GetY());
-			control->SetToolTip( _( "Year" ));
+	case TBS_NBYEARS:
+		control = new wxSpinCtrl( toolbar, item, wxT(""), wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 1, 10);
+		control->SetSize( 60, control->GetBestSize().GetY());
+		control->SetToolTip( _( "Number of Years" ));
 		break;
-		case TBS_NBYEARS:
-			control = new wxSpinCtrl( toolbar, item, wxT(""), wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 1, 10);
-			control->SetSize( 60, control->GetBestSize().GetY());
-			control->SetToolTip( _( "Number of Years" ));
+	case TBS_ECL_TYPE:
+		control = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 3, eclipse_types, 0);
+		control->SetToolTip( _( "Type" ));
 		break;
-		case TBS_ECL_TYPE:
-			control = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 3, eclipse_types, 0);
-			control->SetToolTip( _( "Type" ));
+	case TBS_DATE_PROGRESS:
+		control = new wxSlider( toolbar, item, 0, -7, 7, wxDefaultPosition, wxSize( 100, -1 ), wxSL_HORIZONTAL );
+		//| wxSL_AUTOTICKS ); | wxSL_LABELS );
+		control->SetToolTip( _( "Progress Transit Date" ));
 		break;
-		case TBS_DATE_PROGRESS:
-			control = new wxSlider( toolbar, item, 0, -7, 7, wxDefaultPosition, wxSize( 100, -1 ), wxSL_HORIZONTAL );
-			//| wxSL_AUTOTICKS ); | wxSL_LABELS );
-			control->SetToolTip( _( "Progress Transit Date" ));
+	case TBS_DATE:
+		control = new DateSpin( toolbar, item );
 		break;
-		case TBS_DATE:
-			control = new DateSpin( toolbar, item, 0 );
+	case TBS_TIME:
+		control = new TimeSpin( toolbar, item );
 		break;
-		case TBS_TIME:
-			control = new TimeSpin( toolbar, item, 0 ); //, wxDefaultPosition, wxSize( 100, 24 ));
+	case TBS_TRANSITMODE:
+		control = new TransitModeChoice( toolbar, item );
 		break;
-		case TBS_TRANSITMODE:
-			control = new TransitModeChoice( toolbar, item );
+	case TBS_YEARLENGTH:
+		control = new YearLengthChoice( toolbar, item, false );
 		break;
-		case TBS_YEARLENGTH:
-			control = new YearLengthChoice( toolbar, item, false );
+	case TBS_ORBIS:
+		//control = new wxSpinCtrl( toolbar, item, wxT(""), wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS | wxTE_PROCESS_ENTER, 0, 150);
+		control = new wxSpinCtrl( toolbar, item, wxT(""), wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, 150);
+		control->SetSize( 60, control->GetBestSize().GetY());
+		control->SetToolTip( _( "Orbis" ));
 		break;
-		case TBS_ORBIS:
-			//control = new wxSpinCtrl( toolbar, item, wxT(""), wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS | wxTE_PROCESS_ENTER, 0, 150);
-			control = new wxSpinCtrl( toolbar, item, wxT(""), wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, 150);
-			control->SetSize( 60, control->GetBestSize().GetY());
-			control->SetToolTip( _( "Orbis" ));
+	case TBS_CIRCLETYPE:
+		control = new CircleTypeChoice( toolbar, item );
 		break;
-		case TBS_CIRCLETYPE:
-			control = new CircleTypeChoice( toolbar, item );
+	case TBS_SORT:
+		control = new SortChoice( toolbar, item );
 		break;
-		case TBS_SORT:
-			control = new SortChoice( toolbar, item );
+	case TBS_FILTER:
+		control =  new FilterChoice( toolbar, item );
 		break;
-		case TBS_FILTER:
-			control =  new FilterChoice( toolbar, item );
+	case TBS_YOGAGROUPFILTER:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
+		choice->SetToolTip( wxT( "Filter for Yoga Types" ));
 		break;
-		case TBS_YOGAGROUPFILTER:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
-			choice->SetToolTip( wxT( "Filter for Yoga Types" ));
+	case TBS_YOGASOURCEFILTER:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
+		choice->SetToolTip( wxT( "Filter for Yoga Sources" ));
 		break;
-		case TBS_YOGASOURCEFILTER:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
-			choice->SetToolTip( wxT( "Filter for Yoga Sources" ));
+	case TBS_YOGAFIRSTHOUSE:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 120, -1 ), 15,
+		                       first_house_choices, wxADJUST_MINSIZE );
+		choice->SetToolTip( wxT( "Define Ascendant" ));
 		break;
-		case TBS_YOGAFIRSTHOUSE:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 120, -1 ), 15,
-				first_house_choices, wxADJUST_MINSIZE );
-			choice->SetToolTip( wxT( "Define Ascendant" ));
+	case TBS_URANIANMODE:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 2, uranian_viewmodes, 0);
+		choice->SetSelection( 0 );
+		choice->SetToolTip( _( "Mode" ));
 		break;
-		case TBS_URANIANMODE:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 2, uranian_viewmodes, 0);
-			choice->SetSelection( 0 );
-			choice->SetToolTip( _( "Mode" ));
+	case TBS_ZOOM:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 10, zoom_choices, 0);
+		choice->SetToolTip( _( "Zoom" ));
 		break;
-		case TBS_ZOOM:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 10, zoom_choices, 0);
-			choice->SetToolTip( _( "Zoom" ));
+	case TBS_ANTARDASALEVEL:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 3, antardasa_choices, 0);
+		choice->SetSelection( 1 );
+		choice->SetToolTip( _( "Dasa Level" ));
 		break;
-		case TBS_ANTARDASALEVEL:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 3, antardasa_choices, 0);
-			choice->SetSelection( 1 );
-			choice->SetToolTip( _( "Dasa Level" ));
+	case TBS_MONTH:
+		control =  new wxSpinCtrl( toolbar, item, wxT(""), wxDefaultPosition, wxDefaultSize,
+		                           wxSP_ARROW_KEYS|wxSP_WRAP|wxTE_PROCESS_ENTER, 1, 12 );
+		control->SetSize( 50, control->GetBestSize().GetY());
+		control->SetToolTip( _( "Month" ));
 		break;
-		case TBS_MONTH:
-			control =  new wxSpinCtrl( toolbar, item, wxT(""), wxDefaultPosition, wxDefaultSize,
-				wxSP_ARROW_KEYS|wxSP_WRAP|wxTE_PROCESS_ENTER, 1, 12 );
-			control->SetSize( 50, control->GetBestSize().GetY());
-			control->SetToolTip( _( "Month" ));
+	case TBS_EPHEMMODE:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 120, -1 ), 6, ephem_mode_choices, 0);
+		choice->SetToolTip( _( "Mode" ));
 		break;
-		case TBS_EPHEMMODE:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 120, -1 ), 6, ephem_mode_choices, 0);
-			choice->SetToolTip( _( "Mode" ));
+	case TBS_TZ:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxDefaultSize, 2, tz_choices, 0);
+		choice->SetToolTip( _( "Time Zone" ));
 		break;
-		case TBS_EPHEMTZ:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 120, -1 ), 2, ephemtz_choices, 0);
-			choice->SetToolTip( _( "Time Zone" ));
+	case TBS_EPHEMDEG:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 120, -1 ), 9, ephemdeg_choices, 0);
+		choice->SetToolTip( _( "Circle Type" ));
 		break;
-		case TBS_EPHEMDEG:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 120, -1 ), 9, ephemdeg_choices, 0);
-			choice->SetToolTip( _( "Circle Type" ));
+	case TBS_PARTNER1:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
+		choice->SetToolTip( _( "Partner 1" ));
 		break;
-		case TBS_PARTNER1:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
-			choice->SetToolTip( _( "Partner 1" ));
+	case TBS_PARTNER2:
+		choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
+		choice->SetToolTip( _( "Partner 2" ));
 		break;
-		case TBS_PARTNER2:
-			choice = new wxChoice( toolbar, item, wxDefaultPosition, wxSize( 150, -1 ));
-			choice->SetToolTip( _( "Partner 2" ));
-		break;
-		default:
-			assert( 0 );
+	default:
+		assert( 0 );
 		break;
 	}
 	assert( choice || control );
@@ -420,60 +447,57 @@ void ToolbarFactory::createChoiceItem( const int &item )
 void ToolbarFactory::createButtonItem( const int &item )
 {
 	IconProvider p;
-	switch( item )
+	switch ( item )
 	{
-		case TBB_NOW:
-			toolbar->AddTool( item, _("Now"), p.getBitmap( BITMAP_NOW ));
+	case TBB_NOW:
+		toolbar->AddTool( item, _("Now"), p.getBitmap( BITMAP_NOW ));
 		break;
-		case TBB_DASA:
-			toolbar->AddTool( item, _("Select Dasas"), p.getBitmap( BITMAP_DASA ));
+	case TBB_DASA:
+		toolbar->AddTool( item, _("Select Dasas"), p.getBitmap( BITMAP_DASA ));
 		break;
-		case TBB_GOTO:
-			toolbar->AddTool( item, _("Goto Year"), p.getBitmap( BITMAP_GOTO ));
+	case TBB_GOTO:
+		toolbar->AddTool( item, _("Goto Year"), p.getBitmap( BITMAP_GOTO ));
 		break;
-		case TBB_NEW:
-			toolbar->AddTool( item, _("New File"), p.getBitmap( BITMAP_NEW ));
+	case TBB_NEW:
+		toolbar->AddTool( item, _("New File"), p.getBitmap( BITMAP_NEW ));
 		break;
-		case TBB_OPEN:
-			toolbar->AddTool( item, _("Open File"), p.getBitmap( BITMAP_OPEN ));
+	case TBB_OPEN:
+		toolbar->AddTool( item, _("Open File"), p.getBitmap( BITMAP_OPEN ));
 		break;
-		case TBB_SAVE:
-			toolbar->AddTool( item, _("Save File"), p.getBitmap( BITMAP_SAVE ));
+	case TBB_SAVE:
+		toolbar->AddTool( item, _("Save File"), p.getBitmap( BITMAP_SAVE ));
 		break;
-		case TBB_SAVEAS:
-			toolbar->AddTool( item, _("Save File As"), p.getBitmap( BITMAP_SAVEAS ));
+	case TBB_SAVEAS:
+		toolbar->AddTool( item, _("Save File As"), p.getBitmap( BITMAP_SAVEAS ));
 		break;
-		case TBB_CLOSE:
-			toolbar->AddTool( item, _("Close Child"), p.getBitmap( BITMAP_CLOSE ));
+	case TBB_CLOSE:
+		toolbar->AddTool( item, _("Close Child"), p.getBitmap( BITMAP_CLOSE ));
 		break;
-		default:
-			assert( 0 );
+	default:
+		assert( 0 );
 		break;
 	}
 }
 
 /*****************************************************
 **
-**   ToolbarFactory   ---    getUsedCommandList
+**   ToolbarFactory   ---    getCommandListFromString
 **
 ******************************************************/
-vector<ToolBarCommand> ToolbarFactory::getUsedCommandList( const bool useConfig )
+vector<ToolBarCommand> ToolbarFactory::getCommandListFromString( wxString toolbarConfig )
 {
 	wxString s;
 	long l;
-	vector<ToolBarCommand> r;
+	vector<ToolBarCommand> ret;
 
-	if ( config->mainToolbarItems.IsEmpty() || ! useConfig ) return getFallbackCommandList();
-	wxStringTokenizer tk( config->mainToolbarItems, wxT( ";" ));
-	while( tk.HasMoreTokens() )
-	{
-	    s = tk.GetNextToken();
-			s.ToLong( &l );
-			ToolBarCommand cmd;
-			getItemById( (int)l, cmd );
-			r.push_back( cmd );
-	}
-	return r;
+  wxStringTokenizer tk( toolbarConfig, wxT( ";" ));
+  while ( tk.HasMoreTokens() )
+  {
+    s = tk.GetNextToken();
+    s.ToLong( &l );
+    ret.push_back( getItemById( (int)l ));
+  }
+	return ret;
 }
 
 /*****************************************************
@@ -481,46 +505,18 @@ vector<ToolBarCommand> ToolbarFactory::getUsedCommandList( const bool useConfig
 **   ToolbarFactory   ---    getItemById
 **
 ******************************************************/
-void ToolbarFactory::getItemById( const int &index, ToolBarCommand &cmd )
+ToolBarCommand ToolbarFactory::getItemById( const int &index )
 {
-	for( unsigned int i = 0; i < cmdlist.size(); i++ )
+	for ( unsigned int i = 0; i < cmdlist.size(); i++ )
 	{
-		if ( cmdlist[i].commandId == (int)index )
+		if ( cmdlist[i].commandId == index )
 		{
-			cmd = cmdlist[i];
-			return;
+			return cmdlist[i];
 		}
 	}
 	//assert( false );
 	printf( "Error in ToolbarFactory::getItemById: cannot find item with index %d\n", index );
-}
-
-/*****************************************************
-**
-**   ToolbarFactory   ---    getUnusedCommandList
-**
-******************************************************/
-vector<ToolBarCommand> ToolbarFactory::getUnusedCommandList( const bool useConfig )
-{
-	vector<ToolBarCommand> commands = getUsedCommandList( useConfig );
-	vector<ToolBarCommand> retlist;
-	bool found;
-	int id;
-	for( unsigned int i = 0; i < cmdlist.size(); i++ )
-	{
-		found = false;
-		id = cmdlist[i].commandId;
-		for( unsigned int j = 0; j < commands.size(); j++ )
-		{
-			if ( commands[j].commandId == id )
-			{
-				found = true;
-				break;
-			}
-		}
-		if ( ! found ) retlist.push_back( cmdlist[i]);
-	}
-	return retlist;
+	return ToolBarCommand();
 }
 
 /*****************************************************
@@ -536,7 +532,7 @@ void ToolbarFactory::init()
 		bool isDefault;
 	}
 	idList[] =
-	{ 
+	{
 		{ APP_FILENEW, true },
 		{ APP_FILEOPEN, true },
 		{ CMD_CHILD_SAVE, true },
@@ -545,7 +541,7 @@ void ToolbarFactory::init()
 		{ CMD_CHILD_QUICKPRINT, false },
 		{ CMD_CHILD_EDITDATA, true },
 		{ 0, true },
-		
+
 		{ CMD_CHILD_NEW_RASI, true },
 		{ CMD_CHILD_NEW_RASI+1, true },
 		{ CMD_CHILD_NEW_RASI+2, false },
@@ -577,9 +573,8 @@ void ToolbarFactory::init()
 		{ CMD_CHILD_NEW_ASHTAKAVARGA, false },
 		{ CMD_CHILD_NEW_TRANSIT, true },
 		{ CMD_CHILD_NEW_YOGA, true },
-		//{ CMD_CHILD_NEW_SHADBALA, false },
 		{ CMD_CHILD_NEW_SOLAR, false },
-	
+
 		{ CMD_CHILD_NEW_URANIAN, false },
 		{ 0, true },
 
@@ -587,7 +582,7 @@ void ToolbarFactory::init()
 		{ APP_NEW_PARTNER, true },
 		{ APP_SHOWEPHEM, true },
 		{ APP_SHOWECLIPSE, false },
-		{ APP_LOCATION, false },
+		{ APP_LOCATION, true },
 		{ APP_CONFIGURE, true },
 		{ APP_HELP, false },
 		{ APP_ABOUT, false }
@@ -599,9 +594,9 @@ void ToolbarFactory::init()
 	for ( size_t i = 0; i < WXSIZEOF(idList); i++ )
 	{
 		command = handler->getCommand( idList[i].cmdId );
-		cmdlist.push_back( ToolBarCommand( idList[i].cmdId, 
-			command ? command->getBitmapId() : 0,
-			command ? command->getText() : wxEmptyString, 
+		cmdlist.push_back(
+			ToolBarCommand( idList[i].cmdId, command ? command->getBitmapId() : 0,
+			command ? command->getText() : wxEmptyString,
 			idList[i].isDefault, idList[i].cmdId? imageId : 0 ));
 		if ( idList[i].cmdId != 0 ) imageId++;
 	}
@@ -609,13 +604,13 @@ void ToolbarFactory::init()
 
 /*****************************************************
 **
-**   ToolbarFactory   ---    getFallbackCommandList
+**   ToolbarFactory   ---    getDefaultCommandList
 **
 ******************************************************/
-vector<ToolBarCommand> ToolbarFactory::getFallbackCommandList()
+vector<ToolBarCommand> ToolbarFactory::getDefaultCommandList()
 {
 	vector<ToolBarCommand> l;
-	for( unsigned int i = 0; i < cmdlist.size(); i++ )
+	for ( unsigned int i = 0; i < cmdlist.size(); i++ )
 		if ( cmdlist[i].isDefault ) l.push_back( cmdlist[i] );
 	return l;
 }
