@@ -3,9 +3,9 @@
  *  for Vedic and western astrology.
 
  *  File       src/gui/TransitView.cpp
- *  Release    6.0
- *  Author     M. Pettau
- *  Copyright  2003-2010 by the author
+ *  Release    7.0
+ *  Author     Martin Pettau
+ *  Copyright  2003-2012 by the author
 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -19,7 +19,7 @@
 ****************************************************************************/
 
 #ifdef __GNUG__
-	#pragma implementation "TransitView.h"
+#pragma implementation "TransitView.h"
 #endif
 
 #include "TransitView.h"
@@ -29,6 +29,7 @@
 #include <wx/slider.h>
 #include <wx/spinctrl.h>
 #include <wx/statbox.h>
+#include <wx/timer.h>
 #include <wx/toolbar.h>
 
 #include "Aspect.h"
@@ -44,9 +45,8 @@
 #include "guibase.h"
 #include "IconProvider.h"
 #include "GraphicGrid.h"
-#include "MenuProvider.h"
-#include "Nakshatra.h"
 #include "NotebookWidget.h"
+#include "mathbase.h"
 #include "Painter.h"
 #include "SbcView.h"
 #include "SplitterWidget.h"
@@ -60,9 +60,10 @@
 
 extern Config *config;
 
-enum { TRANSIT_NOTEBOOK = wxID_HIGHEST + 3000 };
+enum { TRANSIT_NOTEBOOK = wxID_HIGHEST + 3000, TRANSIT_PROGRRESS_TIMER };
 
 #define MAX_TRANSIT_PAGES 6
+#define TIMER_PERIOD  100
 
 enum { TNB_DOUBLE = 0, TNB_SBC, TNB_SHADVARGA, TNB_VARGA2, TNB_VARGA3, TNB_URANIAN };
 
@@ -71,12 +72,12 @@ IMPLEMENT_CLASS( TransitChartWidget, BasicWidget )
 
 /*****************************************************
 **
-**   TransitChartWidget   ---   Constructor 
+**   TransitChartWidget   ---   Constructor
 **
 ******************************************************/
 TransitChartWidget::TransitChartWidget( wxWindow *parent, ChartProperties *chartprops, const Horoscope *h1, const Horoscope *h2, const bool &vedic,
-		const wxPoint& pos, const wxSize& size )
- : BasicWidget( parent, chartprops, -1, pos, size ),
+                                        const wxPoint& pos, const wxSize& size )
+		: BasicWidget( parent, chartprops, -1, pos, size ),
 		doc( h1 ),
 		htransit( h2 )
 {
@@ -89,7 +90,7 @@ TransitChartWidget::TransitChartWidget( wxWindow *parent, ChartProperties *chart
 
 /*****************************************************
 **
-**   TransitChartWidget   ---   Destructor 
+**   TransitChartWidget   ---   Destructor
 **
 ******************************************************/
 TransitChartWidget::~TransitChartWidget()
@@ -121,22 +122,22 @@ void TransitChartWidget::doPaint( bool eraseBackground, const wxRect* rect )
 	painter->setBrushColor( config->colors->bgColor );
 	painter->drawRectangle( 0, 0, w, h );
 
-	wchart->paint( painter, wxRect( 0, 0, w, h ));
+	wchart->paint( painter, MyRect( 0, 0, w, h ));
 }
 
 /*************************************************//**
 *
-*  
+*
 *
 ******************************************************/
-class TransitTextWidget : public TextWidget 
+class TransitTextWidget : public TextWidget
 {
 	DECLARE_CLASS( TransitTextWidget )
-	
+
 public:
 	TransitTextWidget( wxWindow *parent, BasicView *v, TransitExpert *expert, const int textmode )
-		: TextWidget( parent, v ),
-		textmode( textmode )
+			: TextWidget( parent, v ),
+			textmode( textmode )
 	{
 		this->expert = expert;
 	}
@@ -151,78 +152,84 @@ public:
 
 private:
 	const int textmode;
-	
+
 };
 
 IMPLEMENT_CLASS( TransitTextWidget, TextWidget )
 
 /*****************************************************
 **
-**   TransitView   ---   Constructor 
+**   TransitView   ---   Constructor
 **
 ******************************************************/
 TransitView::TransitView( wxWindow *parent, ChildWindow *frame, Document *doc, const bool &vedic )
- : BasicNotebookView( parent, frame, doc, VIEW_TRANSIT, true, vedic )
+		: BasicNotebookView( parent, frame, doc, VIEW_TRANSIT, true, vedic )
 {
 	supportObjectToggle = true;
 
 	expert = new TransitExpert( doc, this );
-	expert->update();
+
+	tzchoice = config->transitTimezone;
+	transitdate = JDate::getCurrentJD();
+	calcTzOffset();
 
 	notebook = new NotebookWidget( this, BASIC_NOTEBOOK, wxDefaultPosition, wxDefaultSize, wxNB_DEFAULT );
 	initToolItems();
 
-	for( int i = 0; i < MAX_TRANSIT_PAGES; i++ )
+	for ( int i = 0; i < MAX_TRANSIT_PAGES; i++ )
 	{
-		switch( i )
+		switch ( i )
 		{
-			case TNB_DOUBLE:
-				tsplitter = new SplitterWidget( notebook );
-				aspectText = new TransitTextWidget( tsplitter, this, expert, 0 );
-				gwidget =  new ChartGridWidget( tsplitter, this, 1, 1 );
-				gwidget->addVedicVargaChart( new VedicVargaChart( doc, VARGA_RASI, expert->getTransitChart(), VARGA_RASI, this ));
-				tsplitter->SplitVertically( aspectText, gwidget );
-				notebook->AddPage( tsplitter, _( "Double Chart" ));
+		case TNB_DOUBLE:
+			tsplitter = new SplitterWidget( notebook );
+			aspectText = new TransitTextWidget( tsplitter, this, expert, 0 );
+			gwidget =  new ChartGridWidget( tsplitter, this, 1, 1 );
+			gwidget->addVedicVargaChart( new VedicVargaChart( doc, VARGA_RASI, expert->getTransitChart(), VARGA_RASI, this ));
+			tsplitter->SplitVertically( aspectText, gwidget );
+			notebook->AddPage( tsplitter, _( "Double Chart" ));
 			break;
 
-			case TNB_SBC:
-				swidget = new SbcWidget( notebook, this, (Horoscope*)doc, (Horoscope*)expert->getTransitChart() );
-				notebook->AddPage( swidget, _( "Sarvatobhadra" ));
+		case TNB_SBC:
+			swidget = new SbcWidget( notebook, this, (Horoscope*)doc, (Horoscope*)expert->getTransitChart() );
+			notebook->AddPage( swidget, _( "Sarvatobhadra" ));
 			break;
 
-			case TNB_SHADVARGA:
-				shadvargawidget = new ShadVargaChartGridWidget( notebook, this, doc, expert->getTransitChart());
-				notebook->AddPage( shadvargawidget, _( "Shadvarga" ));
+		case TNB_SHADVARGA:
+			shadvargawidget = new ShadVargaChartGridWidget( notebook, this, doc, expert->getTransitChart());
+			notebook->AddPage( shadvargawidget, _( "Shadvarga" ));
 			break;
 
-			case TNB_VARGA2:
-				varga2widget = new VargaTab2ChartGridWidget( notebook, this, doc, expert->getTransitChart());
-				notebook->AddPage( varga2widget, _( "Varga (2)" ));
+		case TNB_VARGA2:
+			varga2widget = new VargaTab2ChartGridWidget( notebook, this, doc, expert->getTransitChart());
+			notebook->AddPage( varga2widget, _( "Varga (2)" ));
 			break;
 
-			case TNB_VARGA3:
-				varga3widget = new VargaTab3ChartGridWidget( notebook, this, doc, expert->getTransitChart());
-				notebook->AddPage( varga3widget, _( "Varga (3)" ));
+		case TNB_VARGA3:
+			varga3widget = new VargaTab3ChartGridWidget( notebook, this, doc, expert->getTransitChart());
+			notebook->AddPage( varga3widget, _( "Varga (3)" ));
 			break;
 
-			case TNB_URANIAN:
-				uranianText = new TransitTextWidget( notebook, this, expert, 1 );
-				notebook->AddPage( uranianText, _( "Uranian" ));
+		case TNB_URANIAN:
+			uranianText = new TransitTextWidget( notebook, this, expert, 1 );
+			notebook->AddPage( uranianText, _( "Uranian" ));
 			break;
 
-			default:
-				printf( "Error: wrong notebook index %d in TransitView::TransitView\n", i );
+		default:
+			printf( "Error: wrong notebook index %d in TransitView::TransitView\n", i );
 			break;
 		}
 	}
 
 	widget = notebook;
+	timer = new wxTimer( this, TRANSIT_PROGRRESS_TIMER );
 
 	Connect( TBB_NOW, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( TransitView::OnSetToCurrent ));
-	Connect( TBS_DATE, COMMAND_DATE_SPIN_CHANGED, wxCommandEventHandler( TransitView::OnDateCtrlChanged ));
-	Connect( TBS_TIME, COMMAND_TIME_SPIN_CHANGED, wxCommandEventHandler( TransitView::OnDateCtrlChanged ));
-	Connect( TBS_TIME, COMMAND_TIME_SPIN_WRAP, wxCommandEventHandler( TransitView::OnTimeCtrlWrap ));
+	Connect( TBS_DATE, COMMAND_SPIN_CHANGED, wxCommandEventHandler( TransitView::OnDateCtrlChanged ));
+	Connect( TBS_DATE, wxEVT_COMMAND_TEXT_UPDATED, wxCommandEventHandler( TransitView::OnDateCtrlChanged ));
+	Connect( TBS_TIME, COMMAND_SPIN_CHANGED, wxCommandEventHandler( TransitView::OnDateCtrlChanged ));
+	Connect( TBS_TIME, COMMAND_SPIN_WRAP, wxCommandEventHandler( TransitView::OnTimeCtrlWrap ));
 
+	Connect( TBS_TZ, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler( TransitView::OnChoiceTimezone ));
 	Connect( TBS_TRANSITMODE, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler( TransitView::OnChoiceCommand ));
 	Connect( TBS_YEARLENGTH, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler( TransitView::OnChoiceCommand ));
 	Connect( TBS_ORBIS, wxEVT_COMMAND_SPINCTRL_UPDATED, wxSpinEventHandler( TransitView::OnSpinCommand ));
@@ -231,23 +238,32 @@ TransitView::TransitView( wxWindow *parent, ChildWindow *frame, Document *doc, c
 	Connect( TBS_CIRCLETYPE, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler( TransitView::OnChoiceCommand ));
 	Connect( wxEVT_IDLE, wxIdleEventHandler( TransitView::OnIdle ));
 
-	Connect( TBS_DATE_PROGRESS, wxEVT_SCROLL_CHANGED, wxScrollEventHandler( TransitView::OnDateProgress ));
-	Connect( TBS_DATE_PROGRESS, wxEVT_SCROLL_THUMBRELEASE, wxScrollEventHandler( TransitView::OnDateProgress ));
-	Connect( BASIC_NOTEBOOK, wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGED, wxNotebookEventHandler( TransitView::OnNotebook ));
+	Connect( TBS_DATE_PROGRESS, wxEVT_SCROLL_THUMBTRACK, wxScrollEventHandler( TransitView::OnDateProgress ));
 
-	OnDataChanged();
+	Connect( TBS_DATE_PROGRESS, wxEVT_SCROLL_THUMBRELEASE, wxScrollEventHandler( TransitView::OnDateProgress ));
+	Connect( TBS_DATE_PROGRESS, wxEVT_SCROLL_CHANGED, wxScrollEventHandler( TransitView::OnDateProgress ));
+
+	Connect( TRANSIT_PROGRRESS_TIMER, wxEVT_TIMER, wxTimerEventHandler( TransitView::OnTimer ));
 }
 
 /*****************************************************
 **
-**   TransitView   ---   Destructor 
+**   TransitView   ---   Destructor
 **
 ******************************************************/
 TransitView::~TransitView()
 {
-  config->sashTransit = tsplitter->GetSashPosition();
+	if ( timer->IsRunning() ) timer->Stop();
+
+	config->sashTransit = tsplitter->GetSashPosition();
+
 	wxSpinCtrl *spin_orbis = (wxSpinCtrl*)toolbar->FindControl( TBS_ORBIS );
-	if( spin_orbis ) config->orbisTransit = spin_orbis->GetValue();
+	if ( spin_orbis ) config->orbisTransit = spin_orbis->GetValue();
+
+	config->transitTimezone = tzchoice;
+
+	config->avtivePageTransit = activepage;
+
 	delete expert;
 }
 
@@ -258,39 +274,152 @@ TransitView::~TransitView()
 ******************************************************/
 void TransitView::postCreate()
 {
-	//printf( "Post Create in TransitView active %d sash %d\n", config->avtivePageTransit, config->sashTransit );
-  assert( tsplitter );
-  tsplitter->SetSashPosition( config->sashTransit );
-  notebook->SetSelection( config->avtivePageTransit );
+	assert( tsplitter );
+	tsplitter->SetSashPosition( config->sashTransit );
+	notebook->SetSelection( config->avtivePageTransit );
+	setToCurrent();
+	dirty = true;
 }
 
 /*****************************************************
 **
-**   TransitView   ---   dispatchCommand 
+**   TransitView   ---   calcTzOffset
+**
+******************************************************/
+void TransitView::calcTzOffset()
+{
+	if ( tzchoice == 1 )
+	{
+		TzUtil tzu;
+		TzInfo tzinfo = tzu.calculateTzInfoForJD( transitdate );
+		tzoffset = tzinfo.tzhours + tzinfo.dsthours;
+	}
+	else tzoffset = 0;
+}
+
+/*****************************************************
+**
+**   TransitView   ---   OnChoiceTimezone
+**
+******************************************************/
+void TransitView::OnChoiceTimezone( wxCommandEvent &event )
+{
+	if ( event.GetInt())
+	{
+		// local time switched on: set tzoffset, add tzoffset later
+		tzchoice = 1;
+		calcTzOffset();
+		transitdate += tzoffset / 24;
+	}
+	else
+	{
+		// local time switched off: adjust transitdate, set tzoffset later
+		transitdate -= tzoffset / 24;
+		tzchoice = 0;
+		calcTzOffset();
+	}
+	setDateTimeSpinsFromTransitdate();
+}
+
+/*****************************************************
+**
+**   TransitView   ---   setTransitdateFromDateTimeSpins
+**
+******************************************************/
+void TransitView::setTransitdateFromDateTimeSpins()
+{
+	if ( toolbar )
+	{
+		// Date and Time
+		DateSpin *spin_date = (DateSpin*)toolbar->FindControl( TBS_DATE );
+		TimeSpin *spin_time = (TimeSpin*)toolbar->FindControl( TBS_TIME );
+		if ( spin_date && spin_time )
+		{
+			double dd = spin_date->getDoubleValue();
+			double tt = spin_time->getDoubleValue();
+			transitdate = dd + tt / 24.0;
+		}
+	}
+	dirty = true;
+}
+
+/*****************************************************
+**
+**   TransitView   ---   setDateTimeSpinsFromTransitdate
+**
+******************************************************/
+void TransitView::setDateTimeSpinsFromTransitdate()
+{
+	if ( toolbar )
+	{
+		DateSpin *spin_date = (DateSpin*)toolbar->FindControl( TBS_DATE );
+		TimeSpin *spin_time = (TimeSpin*)toolbar->FindControl( TBS_TIME );
+		if ( spin_date && spin_time )
+		{
+			double thedate = (int)(transitdate + .5 );
+			spin_date->setDoubleValue( thedate -.5 );
+
+			double thetime = ( transitdate - (long)transitdate ) + .5;
+			thetime = a_red( 24.0 * thetime, 24 );
+			spin_time->setDoubleValue( thetime );
+		}
+	}
+	dirty = true;
+}
+
+/*****************************************************
+**
+**   TransitView   ---   setToCurrent
+**
+******************************************************/
+void TransitView::setToCurrent()
+{
+	transitdate = JDate::getCurrentJD() + tzoffset / 24.0;
+	setDateTimeSpinsFromTransitdate();
+}
+
+/*****************************************************
+**
+**   TransitView   ---   OnDateCtrlChanged
+**
+******************************************************/
+void TransitView::OnDateCtrlChanged( wxCommandEvent &event )
+{
+	setTransitdateFromDateTimeSpins();
+	event.Skip();
+}
+
+/*****************************************************
+**
+**   TransitView   ---   OnTimeCtrlWrap
+**
+******************************************************/
+void TransitView::OnTimeCtrlWrap( wxCommandEvent &event )
+{
+	setTransitdateFromDateTimeSpins();
+	transitdate += event.GetInt();
+	setDateTimeSpinsFromTransitdate();
+}
+
+/*****************************************************
+**
+**   TransitView   ---   dispatchCommand
 **
 ******************************************************/
 bool TransitView::dispatchCommand( const int &command )
 {
 	switch ( command )
 	{
-		case CMD_CHILD_TRANSIT_PLUS:
-			//printf( "PLUS\n" );
-			//progress( 1 );
+	case CMD_CHILD_EXPORT:
+		if ( activewidget ) activewidget->doExport();
+		else printf( "Error: no graphic export possible on page %d\n", activepage );
 		break;
-		case CMD_CHILD_TRANSIT_MINUS:
-			//progress( -1 );
-			//printf( "MINUS\n" );
+	case CMD_CHILD_SAVETEXT:
+		if ( activetext ) activetext->doExport();
+		else printf( "Error: no text export possible on page %d\n", activepage );
 		break;
-		case CMD_CHILD_EXPORT:
-			if ( activewidget ) activewidget->doExport();
-			else printf( "Error: no graphic export possible on page %d\n", activepage );
-		break;
-		case CMD_CHILD_SAVETEXT:
-			if ( activetext ) activetext->doExport();
-			else printf( "Error: no text export possible on page %d\n", activepage );
-		break;
-		default:
-			return BasicView::dispatchCommand( command );
+	default:
+		return BasicView::dispatchCommand( command );
 		break;
 	}
 	return true;
@@ -303,18 +432,18 @@ bool TransitView::dispatchCommand( const int &command )
 ******************************************************/
 bool TransitView::supportsEWToggle() const
 {
-	switch( activepage )
+	switch ( activepage )
 	{
-		case TNB_SBC:
-		case TNB_SHADVARGA:
-		case TNB_VARGA2:
-		case TNB_VARGA3:
-			return false;
+	case TNB_SBC:
+	case TNB_SHADVARGA:
+	case TNB_VARGA2:
+	case TNB_VARGA3:
+		return false;
 		break;
-		case TNB_DOUBLE:
-		case TNB_URANIAN:
-		default:
-			return true;
+	case TNB_DOUBLE:
+	case TNB_URANIAN:
+	default:
+		return true;
 		break;
 	}
 	return true;
@@ -380,41 +509,6 @@ bool TransitView::isVedic() const
 	return( supportsEWToggle() ? ChartProperties::isVedic() : true );
 }
 
-/*****************************************************
-**
-**   TransitView   ---   OnDateCtrlChanged
-**
-******************************************************/
-void TransitView::OnDateCtrlChanged( wxCommandEvent &event )
-{
-	double tz = config->defaultLocation.getTimeZone() + config->defaultLocation.getDST();
-	if ( toolbar )
-	{
-		DateSpin *spin_date = (DateSpin*)toolbar->FindControl( TBS_DATE );
-		TimeSpin *spin_time = (TimeSpin*)toolbar->FindControl( TBS_TIME );
-		if ( spin_date && spin_time )
-		{
-			double jd = spin_date->getJD() - .5 + ( spin_time->getTime() - tz ) / 24;
-			expert->setTransitDate( jd );
-		}
-	}
-	OnDataChanged();
-}
-
-/*****************************************************
-**
-**   TransitView   ---   OnTimeCtrlWrap
-**
-******************************************************/
-void TransitView::OnTimeCtrlWrap( wxCommandEvent &event )
-{
-	if ( toolbar )
-	{
-		DateSpin *spin_date = (DateSpin*)toolbar->FindControl( TBS_DATE );
-		if ( spin_date ) spin_date->setDate( spin_date->getJD() + event.GetInt());
-	}
-}
-
 /**************************************************************
 ***
 **   TransitView   ---   initToolItems
@@ -427,21 +521,23 @@ void TransitView::initToolItems()
 		wxChoice *choice_mode = (wxChoice*)toolbar->FindControl( TBS_TRANSITMODE );
 		if ( choice_mode ) choice_mode->SetSelection( config->transitModus );
 
+		wxChoice *choice_tz = (wxChoice*)toolbar->FindControl( TBS_TZ );
+		if ( choice_tz ) choice_tz->SetSelection( tzchoice );
+
 		YearLengthChoice *choice_yl = (YearLengthChoice*)toolbar->FindControl( TBS_YEARLENGTH );
-		if( choice_yl )
-		{
-			choice_yl->SetSelection( config->wYearLength );
-		}
+		if ( choice_yl ) choice_yl->SetSelection( config->wYearLength );
 
 		wxSpinCtrl *spin_orbis = (wxSpinCtrl*)toolbar->FindControl( TBS_ORBIS );
-		if( spin_orbis ) spin_orbis->SetValue( config->orbisTransit );
+		if ( spin_orbis ) spin_orbis->SetValue( config->orbisTransit );
 
 		CircleTypeChoice *choice_degree = (CircleTypeChoice*)toolbar->FindControl( TBS_CIRCLETYPE );
-		if( choice_degree ) choice_degree->SetSelection( config->circleType );
+		if ( choice_degree ) choice_degree->SetSelection( config->circleType );
 
 		SortChoice *choice_sort = (SortChoice*)toolbar->FindControl( TBS_SORT );
-		if( choice_sort ) choice_sort->SetSelection( config->planetSortOrder );
+		if ( choice_sort ) choice_sort->SetSelection( config->planetSortOrder );
 	}
+
+	setDateTimeSpinsFromTransitdate();
 }
 
 /*****************************************************
@@ -453,28 +549,28 @@ double TransitView::getDeltaValue( const int &v )
 {
 	double ret = 0;
 	int val = v > 0 ? v : -v;
-	switch( val )
+	switch ( val )
 	{
-		case 1: // second
-			ret = 1/ 86400.0;	
+	case 1: // second
+		ret = 1/ 86400.0;
 		break;
-		case 2: // Minute
-			ret = 1/ 1440.0;	
+	case 2: // Minute
+		ret = 1/ 1440.0;
 		break;
-		case 3: // hour
-			ret = 1/ 24.0;	
+	case 3: // hour
+		ret = 1/ 24.0;
 		break;
-		case 4: // day
-			ret = 1.0;	
+	case 4: // day
+		ret = 1.0;
 		break;
-		case 5: // week
-			ret = 7.0;	
+	case 5: // week
+		ret = 7.0;
 		break;
-		case 6: // month
-			ret = 30.0;	
+	case 6: // month
+		ret = 30.0;
 		break;
-		case 7: //year
-			ret = 365.25;	
+	case 7: //year
+		ret = 365.25;
 		break;
 	}
 	if ( v < 0 ) ret *= -1;
@@ -493,6 +589,27 @@ void TransitView::OnDateProgress( wxScrollEvent &event )
 	{
 		resetSlider();
 	}
+	else if ( type == wxEVT_SCROLL_THUMBTRACK )
+	{
+		if ( ! timer->IsRunning() )
+		{
+			timer->Start( TIMER_PERIOD );
+		}
+	}
+	dirty = true;
+}
+
+/**************************************************************
+***
+**   TransitView   ---   getSliderValue
+***
+***************************************************************/
+int TransitView::getSliderValue()
+{
+	int delta = 0;
+	wxSlider *slider = (wxSlider*)toolbar->FindControl( TBS_DATE_PROGRESS );
+	if ( slider ) delta = slider->GetValue();
+	return delta;
 }
 
 /**************************************************************
@@ -507,6 +624,32 @@ void TransitView::resetSlider()
 		wxSlider *slider = (wxSlider*)toolbar->FindControl( TBS_DATE_PROGRESS );
 		if ( slider ) slider->SetValue( 0 );
 	}
+	if ( timer->IsRunning() )
+	{
+		timer->Stop();
+	}
+	dirty = true;
+}
+
+/**************************************************************
+***
+**   TransitView   ---   OnTimer
+***
+***************************************************************/
+void TransitView::OnTimer( wxTimerEvent &event )
+{
+	int delta = getSliderValue();
+	if ( delta == 0 )
+	{
+		timer->Stop();
+	}
+	else
+	{
+		transitdate += getDeltaValue( delta );
+		setDateTimeSpinsFromTransitdate();
+		OnDataChanged();
+	}
+	dirty = true;
 }
 
 /**************************************************************
@@ -516,17 +659,7 @@ void TransitView::resetSlider()
 ***************************************************************/
 void TransitView::OnIdle( wxIdleEvent &event )
 {
-	int delta = 0;
-	if ( toolbar )
-	{
-		wxSlider *slider = (wxSlider*)toolbar->FindControl( TBS_DATE_PROGRESS );
-		if ( slider ) delta = slider->GetValue();
-		if ( delta != 0 )
-		{
-			expert->setTransitDate( expert->getTransitDate() + getDeltaValue( delta ));
-			OnDataChanged();
-		}
-	}
+	if ( dirty ) OnDataChanged();
 }
 
 /*****************************************************
@@ -536,7 +669,7 @@ void TransitView::OnIdle( wxIdleEvent &event )
 ******************************************************/
 void TransitView::OnToolbarCommand()
 {
-	OnDataChanged();
+	dirty = true;
 }
 
 /*****************************************************
@@ -549,17 +682,14 @@ void TransitView::OnDataChanged()
 	int transitmode = 0;
 	BasicView::OnDataChanged();
 
-//enum { TNB_DOUBLE = 0, TNB_SBC, TNB_SHADVARGA, TNB_VARGA2, TNB_VARGA3, TNB_URANIAN };
+	// must be called each time because dst may have changed
+	calcTzOffset();
+
 	if ( toolbar )
 	{
 		// Date and Time
-		DateSpin *spin_date = (DateSpin*)toolbar->FindControl( TBS_DATE );
-		TimeSpin *spin_time = (TimeSpin*)toolbar->FindControl( TBS_TIME );
-		if ( spin_date && spin_time )
-		{
-			spin_date->setDate( expert->getTransitDate());
-			spin_time->setDate( expert->getTransitDate());
-		}
+		setTransitdateFromDateTimeSpins();
+		expert->setTransitDate( transitdate, tzoffset );
 
 		// Mode
 		wxChoice *choice_mode = (wxChoice*)toolbar->FindControl( TBS_TRANSITMODE );
@@ -574,9 +704,10 @@ void TransitView::OnDataChanged()
 		YearLengthChoice *choice_yl = (YearLengthChoice*)toolbar->FindControl( TBS_YEARLENGTH );
 		if ( choice_yl )
 		{
-			choice_yl->Enable( transitmode != 0 );
+			ADJUST_TOOLBAR_ITEM ( choice_yl, transitmode != 0 );
 			double yearlength = calcYearLength( choice_yl->GetSelection(), false );
 			expert->setYearLength( yearlength );
+			config->wYearLength = choice_yl->GetSelection();
 		}
 
 		// sort order
@@ -584,7 +715,8 @@ void TransitView::OnDataChanged()
 		if ( choice_sort )
 		{
 			expert->setSortOrder( choice_sort->GetSelection() );
-			choice_sort->Enable( activepage == TNB_URANIAN );
+			ADJUST_TOOLBAR_ITEM( choice_sort, activepage == TNB_URANIAN );
+			config->planetSortOrder = choice_sort->GetSelection();
 		}
 
 		// Orbis (uranian only)
@@ -592,14 +724,14 @@ void TransitView::OnDataChanged()
 		if ( spin_orbis )
 		{
 			expert->setOrbis( spin_orbis->GetValue() / 60.0 );
-			spin_orbis->Enable( activepage == TNB_URANIAN );
+			ADJUST_TOOLBAR_ITEM( spin_orbis, activepage == TNB_URANIAN );
 		}
 
 		CircleTypeChoice *choice_degree = (CircleTypeChoice*)toolbar->FindControl( TBS_CIRCLETYPE );
 		if ( choice_degree )
 		{
 			expert->setCircleDegrees( choice_degree->GetSelection() );
-			choice_degree->Enable( activepage == TNB_URANIAN );
+			ADJUST_TOOLBAR_ITEM( choice_degree, activepage == TNB_URANIAN );
 		}
 
 	}
@@ -617,6 +749,7 @@ void TransitView::OnDataChanged()
 		swidget->OnDataChanged();
 	}
 	if ( activewidget ) activewidget->Refresh();
+	dirty = false;
 }
 
 /*****************************************************
@@ -627,8 +760,7 @@ void TransitView::OnDataChanged()
 void TransitView::OnSetToCurrent( wxCommandEvent &event )
 {
 	resetSlider();
-	expert->setTransitDate( JDate().getJD());
-	OnDataChanged();
+	setToCurrent();
 }
 
 /*****************************************************
@@ -659,44 +791,43 @@ void TransitView::writeUranianText()
 void TransitView::OnNotebook( wxNotebookEvent &event )
 {
 	activepage = event.GetSelection();
-	switch( activepage )
+	switch ( activepage )
 	{
-		case TNB_DOUBLE:
-			activetext = aspectText;
-			activewidget = gwidget;
+	case TNB_DOUBLE:
+		activetext = aspectText;
+		activewidget = gwidget;
 		break;
 
-		case TNB_SBC:
-			activetext = 0;
-			activewidget = swidget;
+	case TNB_SBC:
+		activetext = 0;
+		activewidget = swidget;
 		break;
 
-		case TNB_SHADVARGA:
-			activetext = 0;
-			activewidget = shadvargawidget;
+	case TNB_SHADVARGA:
+		activetext = 0;
+		activewidget = shadvargawidget;
 		break;
 
-		case TNB_VARGA2:
-			activetext = 0;
-			activewidget = varga2widget;
+	case TNB_VARGA2:
+		activetext = 0;
+		activewidget = varga2widget;
 		break;
 
-		case TNB_VARGA3:
-			activetext = 0;
-			activewidget = varga3widget;
+	case TNB_VARGA3:
+		activetext = 0;
+		activewidget = varga3widget;
 		break;
 
-		case TNB_URANIAN:
-			activetext = uranianText;
-			activewidget = 0;
+	case TNB_URANIAN:
+		activetext = uranianText;
+		activewidget = 0;
 		break;
 
-		default:
-			printf( "Error: wrong notebook index %d in TransitView::OnNotebook\n", activepage );
+	default:
+		printf( "Error: wrong notebook index %d in TransitView::OnNotebook\n", activepage );
 		break;
 	}
 	OnDataChanged();
-  config->avtivePageTransit = activepage;
 }
 
 /**************************************************************
